__all__=['', 'NetGetJoinInformation', 'NetGroupGetInfo', 'NetGroupGetUsers', 'NetGroupSetUsers', 'NetGroupSetInfo', 'NetGroupAdd', 'NetGroupAddUser', 'NetGroupDel', 'NetGroupDelUser', 'NetGroupEnum', 'NetGroupAdd', 'NetLocalGroupAddMembers', 'NetLocalGroupDelMembers', 'NetGroupDel', 'NetGroupEnum', 'NetGroupGetInfo', 'NetLocalGroupGetMembers', 'NetGroupSetInfo', 'NetLocalGroupSetMembers', 'NetMessageBufferSend', 'NetMessageNameAdd', 'NetMessageNameDel', 'NetMessageNameEnum', 'NetServerEnum', 'NetServerGetInfo', 'NetServerSetInfo', 'NetShareAdd', 'NetShareDel', 'NetShareCheck', 'NetShareEnum', 'NetShareGetInfo', 'NetShareSetInfo', 'NetUserAdd', 'NetUserChangePassword', 'NetUserEnum', 'NetUserGetGroups', 'NetUserGetInfo', 'NetUserGetLocalGroups', 'NetUserSetInfo', 'NetUserDel', 'NetUserModalsGet', 'NetUserModalsSet', 'NetWkstaUserEnum', 'NetWkstaGetInfo', 'NetWkstaSetInfo', 'NetWkstaTransportEnum', 'NetWkstaTransportAdd', 'NetWkstaTransportDel', 'NetServerDiskEnum', 'NetUseAdd', 'NetUseDel', 'NetUseEnum', 'NetUseGetInfo', 'NetGetAnyDCName', 'NetGetDCName', 'NetSessionEnum', 'NetSessionDel', 'NetSessionGetInfo', 'NetFileEnum', 'NetFileClose', 'NetFileGetInfo', 'NetStatisticsGet', 'NetServerComputerNameAdd', 'NetServerComputerNameDel', 'NetValidateName', 'NetValidatePasswordPolicy']
import typing
import win32typing
"""A module encapsulating the Windows Network API."""


def NetGetJoinInformation() -> 'typing.Tuple[str, typing.Any]':
    """
    Retrieves join status information for the specified 

computer.

Args:



Returns:

      typing.Tuple[str, typing.Any]
        
    """
    pass
        

def NetGroupGetInfo(server:'typing.Union[str]',groupname:'typing.Union[str]',level:'typing.Any') -> 'typing.Any':
    """
    Retrieves information about a particular group on a server.

Args:

      server(typing.Union[str]):The name of the server, or None.
      groupname(typing.Union[str]):The group name
      level(typing.Any):The information level contained in the dataWin32 API References

Returns:

      typing.Any:Search for NetGroupGetInfo at msdn, google or google groups.
Return ValueThe result will be a dictionary in one of the PyGROUP_INFO_* 

formats, depending on the level parameter.

        
    """
    pass
        

def NetGroupGetUsers(server:'typing.Union[str]',groupName:'typing.Union[str]',level:'typing.Any',resumeHandle:'typing.Any'=0,prefLen:'typing.Any'=4096) -> 'typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any]':
    """
    Enumerates the users in a group.

Args:

      server(typing.Union[str]):The name of the server, or None.
      groupName(typing.Union[str]):The name of the local group.
      level(typing.Any):The level of data required.
      resumeHandle(typing.Any):A resume handle.  See the return description for more information.
      prefLen(typing.Any):The preferred length of the data buffer.Win32 API References

Returns:

      typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any]:Search for NetGroupGetUsers at msdn, google or google groups.
Return ValueThe result is a list of items read (with each item being a dictionary of format 

PyGROUP_USERS_INFO_*, depending on the level parameter), 

the total available, and a new "resume handle".  The first time you call 

this function, you should pass zero for the resume handle.  If more data 

is available than what was returned, a new non-zero resume handle will be 

returned, which can be used to call the function again to fetch more data. 

This process may repeat, each time with a new resume handle, until zero is 

returned for the new handle, indicating all the data has been read.

        
    """
    pass
        

def NetGroupSetUsers(server:'typing.Union[str]',group:'typing.Union[str]',level:'typing.Any',members:'typing.Tuple[typing.Any, typing.Any]') -> 'None':
    """
    Sets the members of a local group.  Any existing members not listed are 

removed.

Args:

      server(typing.Union[str]):The name of the server, or None.
      group(typing.Union[str]):The group name
      level(typing.Any):The level of information in the data. Must be 0
      members(typing.Tuple[typing.Any, typing.Any]):The list of new members to add.Win32 API References

Returns:

      None
        
    """
    pass
        

def NetGroupSetInfo(server:'typing.Union[str]',groupname:'typing.Union[str]',level:'typing.Any',data:'typing.Any') -> 'None':
    """
    Sets information about a particular group account on a server.

Args:

      server(typing.Union[str]):The name of the server, or None.
      groupname(typing.Union[str]):The group name
      level(typing.Any):The information level contained in the data
      data(typing.Any):A dictionary holding the group data.Win32 API References

Returns:

      None
        
    """
    pass
        

def NetGroupAdd(server:'typing.Union[str]',level:'typing.Any',data:'typing.Any') -> 'None':
    """
    Creates a new group.

Args:

      server(typing.Union[str]):The name of the server, or None.
      level(typing.Any):The information level contained in the data
      data(typing.Any):A dictionary holding the group data.Win32 API References

Returns:

      None
        
    """
    pass
        

def NetGroupAddUser(server:'typing.Union[str]',group:'typing.Union[str]',username:'typing.Union[str]') -> 'None':
    """
    Adds a user to the group

Args:

      server(typing.Union[str]):The name of the server, or None.
      group(typing.Union[str]):The group name
      username(typing.Union[str]):The user to add to the group.Win32 API References

Returns:

      None
        
    """
    pass
        

def NetGroupDel(server:'typing.Union[str]',groupname:'typing.Union[str]') -> 'None':
    """
    Deletes a group.

Args:

      server(typing.Union[str]):The name of the server, or None.
      groupname(typing.Union[str]):The group nameWin32 API References

Returns:

      None
        
    """
    pass
        

def NetGroupDelUser(server:'typing.Union[str]',group:'typing.Union[str]',username:'typing.Union[str]') -> 'None':
    """
    Deletes a user from the group

Args:

      server(typing.Union[str]):The name of the server, or None.
      group(typing.Union[str]):The group name
      username(typing.Union[str]):The user to delete from the group.Win32 API References

Returns:

      None
        
    """
    pass
        

def NetGroupEnum(server:'typing.Union[str]',level:'typing.Any',prefLen:'typing.Any',resumeHandle:'typing.Any'=0) -> 'typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any]':
    """
    Enumerates all groups.

Args:

      server(typing.Union[str]):The name of the server, or None.
      level(typing.Any):The level of data required.
      prefLen(typing.Any):The preferred length of the data buffer.Win32 API References
      resumeHandle(typing.Any):A resume handle.  See the return description for more information.

Returns:

      typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any]:Search for NetGroupEnum at msdn, google or google groups.
Return ValueThe result is a list of items read (with each item being a dictionary of format 

PyGROUP_INFO_*, depending on the level parameter), 

the total available, and a new "resume handle".  The first time you call 

this function, you should pass zero for the resume handle.  If more data 

is available than what was returned, a new non-zero resume handle will be 

returned, which can be used to call the function again to fetch more data. 

This process may repeat, each time with a new resume handle, until zero is 

returned for the new handle, indicating all the data has been read.

        
    """
    pass
        

def NetGroupAdd(server:'typing.Union[str]',level:'typing.Any',data:'typing.Any') -> 'None':
    """
    Creates a new group.

Args:

      server(typing.Union[str]):The name of the server, or None.
      level(typing.Any):The information level contained in the data
      data(typing.Any):A dictionary holding the group data.Win32 API References

Returns:

      None
        
    """
    pass
        

def NetLocalGroupAddMembers(server:'typing.Union[str]',group:'typing.Union[str]',level:'typing.Any',members:'typing.Tuple[typing.Any, typing.Any]') -> 'None':
    """
    Adds users to a local group.

Args:

      server(typing.Union[str]):The name of the server, or None.
      group(typing.Union[str]):The group name
      level(typing.Any):The level of information in the data.
      members(typing.Tuple[typing.Any, typing.Any]):The new members to add.Win32 API References

Returns:

      None
        
    """
    pass
        

def NetLocalGroupDelMembers(server:'typing.Union[str]',group:'typing.Union[str]',members:'typing.List[str]') -> 'None':
    """
    Deletes users from a local group.

Args:

      server(typing.Union[str]):The name of the server, or None.
      group(typing.Union[str]):The group name
      members(typing.List[str]):A list of strings with fully qualified user names to delete from a local group.Win32 API References

Returns:

      None
        
    """
    pass
        

def NetGroupDel(server:'typing.Union[str]',groupname:'typing.Union[str]') -> 'None':
    """
    Deletes a group.

Args:

      server(typing.Union[str]):The name of the server, or None.
      groupname(typing.Union[str]):The group nameWin32 API References

Returns:

      None
        
    """
    pass
        

def NetGroupEnum(server:'typing.Union[str]',level:'typing.Any',prefLen:'typing.Any',resumeHandle:'typing.Any'=0) -> 'typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any]':
    """
    Enumerates all groups.

Args:

      server(typing.Union[str]):The name of the server, or None.
      level(typing.Any):The level of data required.
      prefLen(typing.Any):The preferred length of the data buffer.Win32 API References
      resumeHandle(typing.Any):A resume handle.  See the return description for more information.

Returns:

      typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any]:Search for NetGroupEnum at msdn, google or google groups.
Return ValueThe result is a list of items read (with each item being a dictionary of format 

PyGROUP_INFO_*, depending on the level parameter), 

the total available, and a new "resume handle".  The first time you call 

this function, you should pass zero for the resume handle.  If more data 

is available than what was returned, a new non-zero resume handle will be 

returned, which can be used to call the function again to fetch more data. 

This process may repeat, each time with a new resume handle, until zero is 

returned for the new handle, indicating all the data has been read.

        
    """
    pass
        

def NetGroupGetInfo(server:'typing.Union[str]',groupname:'typing.Union[str]',level:'typing.Any') -> 'typing.Any':
    """
    Retrieves information about a particular group on a server.

Args:

      server(typing.Union[str]):The name of the server, or None.
      groupname(typing.Union[str]):The group name
      level(typing.Any):The information level contained in the dataWin32 API References

Returns:

      typing.Any:Search for NetGroupGetInfo at msdn, google or google groups.
Return ValueThe result will be a dictionary in one of the PyGROUP_INFO_* 

formats, depending on the level parameter.

        
    """
    pass
        

def NetLocalGroupGetMembers(server:'typing.Union[str]',groupName:'typing.Union[str]',level:'typing.Any',resumeHandle:'typing.Any'=0,prefLen:'typing.Any'=4096) -> 'typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any]':
    """
    Enumerates the members in a local 

group.

Args:

      server(typing.Union[str]):The name of the server, or None.
      groupName(typing.Union[str]):The name of the local group.
      level(typing.Any):The level of data required.
      resumeHandle(typing.Any):A resume handle.  See the return description for more information.
      prefLen(typing.Any):The preferred length of the data buffer.Win32 API References

Returns:

      typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any]:Search for NetLocalGroupGetMembers at msdn, google or google groups.
Return ValueThe result is a list of items read (with each item being a dictionary of format 

PyLOCALGROUP_MEMBERS_INFO_*, depending on the level parameter), 

the total available, and a new "resume handle".  The first time you call 

this function, you should pass zero for the resume handle.  If more data 

is available than what was returned, a new non-zero resume handle will be 

returned, which can be used to call the function again to fetch more data. 

This process may repeat, each time with a new resume handle, until zero is 

returned for the new handle, indicating all the data has been read.

        
    """
    pass
        

def NetGroupSetInfo(server:'typing.Union[str]',groupname:'typing.Union[str]',level:'typing.Any',data:'typing.Any') -> 'None':
    """
    Sets information about a particular group account on a server.

Args:

      server(typing.Union[str]):The name of the server, or None.
      groupname(typing.Union[str]):The group name
      level(typing.Any):The information level contained in the data
      data(typing.Any):A dictionary holding the group data.Win32 API References

Returns:

      None
        
    """
    pass
        

def NetLocalGroupSetMembers(server:'typing.Union[str]',group:'typing.Union[str]',level:'typing.Any',members:'typing.Tuple[typing.Any, typing.Any]') -> 'None':
    """
    Sets the members of a local group. Any existing members not listed 

are removed.

Args:

      server(typing.Union[str]):The name of the server, or None.
      group(typing.Union[str]):The group name
      level(typing.Any):The level of information in the data.
      members(typing.Tuple[typing.Any, typing.Any]):The list of new members to add.Win32 API References

Returns:

      None
        
    """
    pass
        

def NetMessageBufferSend(domain:'str',userName:'str',fromName:'str',message:'str') -> 'None':
    """
    sends a string to a registered message alias.

Args:

      domain(str):Specifies the name of the remote server on which the function is to execute. None or empty string the local computer.
      userName(str):Specifies the message name to which the message buffer should be sent.
      fromName(str):The user the message is to come from, or None for the current user.
      message(str):The message textWin32 API References

Returns:

      None
        
    """
    pass
        

def NetMessageNameAdd(server:'typing.Union[typing.Any]',msgname:'typing.Union[typing.Any]') -> 'None':
    """
    Adds a message alias for specified machine

Args:

      server(typing.Union[typing.Any]):Name of server on which to execute - leading backslashes required on NT - local machine used if None
      msgname(typing.Union[typing.Any]):Message alias to add, 15 characters max

Returns:

      None
        
    """
    pass
        

def NetMessageNameDel(server:'typing.Union[typing.Any]',msgname:'typing.Union[typing.Any]') -> 'None':
    """
    Removes a message alias for specified machine

Args:

      server(typing.Union[typing.Any]):Name of server on which to execute - leading backslashes required on NT - local machine used if None
      msgname(typing.Union[typing.Any]):Message alias to delete for specified machine

Returns:

      None
        
    """
    pass
        

def NetMessageNameEnum(Server:'typing.Union[typing.Any]') -> 'None':
    """
    Lists aliases for a computer

Args:

      Server(typing.Union[typing.Any]):Name of server on which to execute - leading backslashes required on NT - local machine used if None

Returns:

      None
        
    """
    pass
        

def NetServerEnum(server:'typing.Union[str]',level:'typing.Any',_type:'typing.Any',prefLen:'typing.Any',domain:'typing.Union[str]'=None,resumeHandle:'typing.Any'=0) -> 'typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any]':
    """
    Retrieves information about each server of a 

particular type

Args:

      server(typing.Union[str]):The name of the server to execute on, or None.
      level(typing.Any):The level of data required.
      _type(typing.Any):Type of server to return - one of the SV_TYPE_* constants.
      prefLen(typing.Any):The preferred length of the data buffer.Win32 API References
      domain(typing.Union[str]):The domain to enumerate, or None for the current domain.
      resumeHandle(typing.Any):A resume handle.  See the return description for more information.

Returns:

      typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any]:Search for NetServerEnum at msdn, google or google groups.
Return ValueThe result is a list of items read (with each item being a dictionary of format 

PySERVER_INFO_*, depending on the level parameter), 

the total available, and a new "resume handle".  The first time you call 

this function, you should pass zero for the resume handle.  If more data 

is available than what was returned, a new non-zero resume handle will be 

returned, which can be used to call the function again to fetch more data. 

This process may repeat, each time with a new resume handle, until zero is 

returned for the new handle, indicating all the data has been read.

        
    """
    pass
        

def NetServerGetInfo(server:'typing.Union[str]',level:'typing.Any') -> 'typing.Any':
    """
    Retrieves information about a particular server.

Args:

      server(typing.Union[str]):The name of the server to execute on, or None.
      level(typing.Any):The information level contained in the dataWin32 API References

Returns:

      typing.Any:Search for NetServerGetInfo at msdn, google or google groups.
Return ValueThe result will be a dictionary in one of the PySERVER_INFO_* 

formats, depending on the level parameter.

        
    """
    pass
        

def NetServerSetInfo(server:'typing.Union[str]',level:'typing.Any',data:'typing.Any') -> 'None':
    """
    Sets information about a particular server.

Args:

      server(typing.Union[str]):The name of the server, or None.
      level(typing.Any):The information level contained in the data
      data(typing.Any):A dictionary holding the share data.Win32 API References

Returns:

      None
        
    """
    pass
        

def NetShareAdd(server:'typing.Union[str]',level:'typing.Any',data:'typing.Any') -> 'None':
    """
    Creates a new share.

Args:

      server(typing.Union[str]):The name of the server, or None.
      level(typing.Any):The information level contained in the data.  Must be level 2 or 502.
      data(typing.Any):A dictionary holding the share data, in the format of SHARE_INFO_*Win32 API References

Returns:

      None
        
    """
    pass
        

def NetShareDel(server:'typing.Union[str]',shareName:'typing.Union[str]',reserved:'typing.Any'=0) -> 'None':
    """
    Deletes a share

Args:

      server(typing.Union[str]):The name of the server, or None.
      shareName(typing.Union[str]):The share name
      reserved(typing.Any):Must be zero.Win32 API References

Returns:

      None
        
    """
    pass
        

def NetShareCheck(server:'typing.Union[str]',deviceName:'typing.Union[str]') -> 'typing.Tuple[typing.Any, typing.Any]':
    """
    Checks if server is sharing a device

Args:

      server(typing.Union[str]):The name of the server, or None.
      deviceName(typing.Union[str]):The share nameWin32 API References

Returns:

      typing.Tuple[typing.Any, typing.Any]:Search for NetShareCheck at msdn, google or google groups.
Return ValueThe result is (1, type-of-device) if device is shared, (0, None) if it is not shared.

        
    """
    pass
        

def NetShareEnum(server:'typing.Union[str]',level:'typing.Any',prefLen:'typing.Any',serverName:'typing.Any',resumeHandle:'typing.Any'=0) -> 'typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any]':
    """
    Retrieves information about each shared resource 

on a server.

Args:

      server(typing.Union[str]):The name of the server, or None.
      level(typing.Any):The level of data required.
      prefLen(typing.Any):The preferred length of the data buffer.Alternative Parameters
      serverName(typing.Any):The name of the server on which the call should execute, or None for the local computer.CommentsIf the old style is used, the result is a list of [(shareName, type, remarks), ...]Win32 API References
      resumeHandle(typing.Any):A resume handle.  See the return description for more information.

Returns:

      typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any]:Search for NetShareEnum 

param 1 is not declared as const :-( at msdn, google or google groups.
Return ValueThe result is a list of items read (with each item being a dictionary of format 

PySHARE_INFO_*, depending on the level parameter), 

the total available, and a new "resume handle".  The first time you call 

this function, you should pass zero for the resume handle.  If more data 

is available than what was returned, a new non-zero resume handle will be 

returned, which can be used to call the function again to fetch more data. 

This process may repeat, each time with a new resume handle, until zero is 

returned for the new handle, indicating all the data has been read.

        
    """
    pass
        

def NetShareGetInfo(server:'typing.Union[str]',netname:'typing.Union[str]',level:'typing.Any') -> 'typing.Any':
    """
    Retrieves information about a particular share on a server.

Args:

      server(typing.Union[str]):The name of the server, or None.
      netname(typing.Union[str]):The network name
      level(typing.Any):The information level contained in the dataWin32 API References

Returns:

      typing.Any:Search for NetShareGetInfo at msdn, google or google groups.
Return ValueThe result will be a dictionary in one of the PySHARE_INFO_* 

formats, depending on the level parameter.

        
    """
    pass
        

def NetShareSetInfo(server:'typing.Union[str]',netname:'typing.Union[str]',level:'typing.Any',data:'typing.Any') -> 'None':
    """
    Sets information about a particular share on a server.

Args:

      server(typing.Union[str]):The name of the server, or None.
      netname(typing.Union[str]):The network name
      level(typing.Any):The information level contained in the data
      data(typing.Any):A dictionary holding the share data.Win32 API References

Returns:

      None
        
    """
    pass
        

def NetUserAdd(server:'typing.Union[str]',level:'typing.Any',data:'typing.Any') -> 'None':
    """
    Creates a new user.

Args:

      server(typing.Union[str]):The name of the server, or None.
      level(typing.Any):The information level contained in the data
      data(typing.Any):A dictionary holding the user data in the format of PyUSER_INFO_*.Win32 API References

Returns:

      None
        
    """
    pass
        

def NetUserChangePassword(server:'typing.Union[str]',username:'typing.Union[str]',oldPassword:'typing.Union[str]',newPassword:'typing.Union[str]') -> 'None':
    """
    Changes the password for a user.

Args:

      server(typing.Union[str]):The name of the server, or None.
      username(typing.Union[str]):The user name, or None for the current username.
      oldPassword(typing.Union[str]):The old password
      newPassword(typing.Union[str]):The new passwordCommentsA server or domain can be configured to require that a user log on to change the password on a user account. If that is the case, you need administrator or account operator access to change the password for another user acount. If logging on is not required, you can change the password for any user account, so long as you know the current password.Win32 API References

Returns:

      None
        
    """
    pass
        

def NetUserEnum(server:'typing.Union[str]',level:'typing.Any',arg:'typing.Any',prefLen:'typing.Any',resumeHandle:'typing.Any'=0) -> 'typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any]':
    """
    Enumerates all users.

Args:

      server(typing.Union[str]):The name of the server, or None.
      level(typing.Any):The level of data required.
      arg(typing.Any):The types of accounts to enumerate.
      prefLen(typing.Any):The preferred length of the data buffer.Win32 API References
      resumeHandle(typing.Any):A resume handle.  See the return description for more information.

Returns:

      typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any]:Search for NetUserEnum at msdn, google or google groups.
Return ValueThe result is a list of items read (with each item being a dictionary of format 

PyUSER_INFO_*, depending on the level parameter), 

the total available, and a new "resume handle".  The first time you call 

this function, you should pass zero for the resume handle.  If more data 

is available than what was returned, a new non-zero resume handle will be 

returned, which can be used to call the function again to fetch more data. 

This process may repeat, each time with a new resume handle, until zero is 

returned for the new handle, indicating all the data has been read.

        
    """
    pass
        

def NetUserGetGroups(serverName:'str',userName:'str') -> 'typing.List[typing.Tuple[typing.Any, typing.Any]]':
    """
    Returns a list of groups,attributes for all groups 

for the user.

Args:

      serverName(str):The name of the remote server on which the function is to execute. None or an empty string specifies the server program running on the local computer.
      userName(str):The name of the user to search for in each group account. To Do This needs to be extended to support the new model, while not breaking existing code.  A default arg would be perfect.Return ValueAlways makes the level 1 call and returns all data. Data return format is a Python List.  Each "Item" is a tuple of (groupname, attributes).  "(s,i)" respectively.  In NT 4 the attributes seem to be hardcoded to 7. Earlier version of NT have not been tested.

Returns:

      typing.List[typing.Tuple[typing.Any, typing.Any]]:The name of the user to search for in each group account. To Do This needs to be extended to support the new model, while 

not breaking existing code.  A default arg would be perfect.
Return ValueAlways makes the level 1 call and returns all data. 

Data return format is a Python List.  Each "Item" 

is a tuple of (groupname, attributes).  "(s,i)" respectively.  In NT 4 the attributes seem to be hardcoded to 7. 

Earlier version of NT have not been tested.

        
    """
    pass
        

def NetUserGetInfo(server:'typing.Union[str]',username:'typing.Union[str]',level:'typing.Any') -> 'typing.Any':
    """
    Retrieves information about a particular user account on a server.

Args:

      server(typing.Union[str]):The name of the server, or None.
      username(typing.Union[str]):The user name
      level(typing.Any):The information level contained in the dataWin32 API References

Returns:

      typing.Any:Search for NetUserGetInfo at msdn, google or google groups.
Return ValueThe result will be a dictionary in one of the PyUSER_INFO_* 

formats, depending on the level parameter.

        
    """
    pass
        

def NetUserGetLocalGroups(serverName:'str',userName:'str',flags:'typing.Any') -> 'typing.List[typing.Any]':
    """
    Retrieves a list of local groups to which a specified user 

belongs.

Args:

      serverName(str):The name of the remote server on which the function is to execute. None or an empty string specifies the server program running on the local computer.
      userName(str):The name of the user to search for in each group account. This parameter can be of the form &ltUserName&gt, in which case the username is expected to be found on servername. The user name can also be of the form &ltDomainName&gt\\&ltUserName&gt in which case &ltDomainName&gt is associated with servername and &ltUserName&gt is expected to be to be found on that domain.
      flags(typing.Any):Flags for the call. To Do This needs to be extended to support the new model, while not breaking existing code.  A default arg would be perfect.

Returns:

      typing.List[typing.Any]
        
    """
    pass
        

def NetUserSetInfo(server:'typing.Union[str]',username:'typing.Union[str]',level:'typing.Any',data:'typing.Any') -> 'None':
    """
    Sets information about a particular user account on a server.

Args:

      server(typing.Union[str]):The name of the server, or None.
      username(typing.Union[str]):The user name
      level(typing.Any):The information level contained in the data
      data(typing.Any):A dictionary holding the user data in the format of PyUSER_INFO_*Win32 API References

Returns:

      None
        
    """
    pass
        

def NetUserDel(server:'typing.Union[str]',username:'typing.Union[str]') -> 'None':
    """
    Deletes a user.

Args:

      server(typing.Union[str]):The name of the server, or None.
      username(typing.Union[str]):The user nameWin32 API References

Returns:

      None
        
    """
    pass
        

def NetUserModalsGet(server:'typing.Union[str]',level:'typing.Any') -> 'typing.Any':
    """
    Retrieves global user information on a server.

Args:

      server(typing.Union[str]):The name of the server, or None.
      level(typing.Any):The information level contained in the dataWin32 API References

Returns:

      typing.Any:Search for NetUserModalsGet at msdn, google or google groups.
Return ValueThe result will be a dictionary in one of the PyUSER_MODALS_INFO_* 

formats, depending on the level parameter.

        
    """
    pass
        

def NetUserModalsSet(server:'typing.Union[str]',level:'typing.Any',data:'typing.Any') -> 'None':
    """
    Sets global user parameters on a server.

Args:

      server(typing.Union[str]):The name of the server, or None.
      level(typing.Any):The information level contained in the data
      data(typing.Any):A dictionary holding the data in the format of PyUSER_MODALS_INFO_*.Win32 API References

Returns:

      None
        
    """
    pass
        

def NetWkstaUserEnum(server:'typing.Union[str]',level:'typing.Any',prefLen:'typing.Any',resumeHandle:'typing.Any'=0) -> 'typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any]':
    """
    Retrieves information about all users 

currently logged on to the workstation.

Args:

      server(typing.Union[str]):The name of the server to execute on, or None.
      level(typing.Any):The level of data required.
      prefLen(typing.Any):The preferred length of the data buffer.Win32 API References
      resumeHandle(typing.Any):A resume handle.  See the return description for more information.

Returns:

      typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any]:Search for NetWkstaUserEnum at msdn, google or google groups.
Return ValueThe result is a list of items read (with each item being a dictionary of format 

PyWKSTA_USER_INFO_*, depending on the level parameter), 

the total available, and a new "resume handle".  The first time you call 

this function, you should pass zero for the resume handle.  If more data 

is available than what was returned, a new non-zero resume handle will be 

returned, which can be used to call the function again to fetch more data. 

This process may repeat, each time with a new resume handle, until zero is 

returned for the new handle, indicating all the data has been read.

        
    """
    pass
        

def NetWkstaGetInfo(server:'typing.Union[str]',level:'typing.Any') -> 'typing.Any':
    """
    Retrieves information about the configuration elements for a workstation

Args:

      server(typing.Union[str]):The name of the server to execute on, or None.
      level(typing.Any):The information level contained in the data. NOTE: levels 302 and 402 don't seem to work correctly. They return error 124. So currently these info levels are not available.Win32 API References

Returns:

      typing.Any:Search for NetWkstaGetInfo at msdn, google or google groups.
Return ValueThe result will be a dictionary in one of the PyWKSTA_INFO_* 

formats, depending on the level parameter.

        
    """
    pass
        

def NetWkstaSetInfo(server:'typing.Union[str]',level:'typing.Any',data:'typing.Any') -> 'None':
    """
    Sets information about the configuration elements for a workstation

Args:

      server(typing.Union[str]):The name of the server, or None.
      level(typing.Any):The information level contained in the data
      data(typing.Any):A dictionary holding the share data.Win32 API References

Returns:

      None
        
    """
    pass
        

def NetWkstaTransportEnum(server:'typing.Union[str]',level:'typing.Any',prefLen:'typing.Any',resumeHandle:'typing.Any'=0) -> 'typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any]':
    """
    Retrieves information about transport 

protocols that are currently managed by the redirector

Args:

      server(typing.Union[str]):The name of the server to execute on, or None.
      level(typing.Any):The level of data required.
      prefLen(typing.Any):The preferred length of the data buffer.Win32 API References
      resumeHandle(typing.Any):A resume handle.  See the return description for more information.

Returns:

      typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any]:Search for NetWkstaTransportEnum at msdn, google or google groups.
Return ValueThe result is a list of items read (with each item being a dictionary of format 

PyWKSTA_TRANSPORT_INFO_*, depending on the level parameter), 

the total available, and a new "resume handle".  The first time you call 

this function, you should pass zero for the resume handle.  If more data 

is available than what was returned, a new non-zero resume handle will be 

returned, which can be used to call the function again to fetch more data. 

This process may repeat, each time with a new resume handle, until zero is 

returned for the new handle, indicating all the data has been read.

        
    """
    pass
        

def NetWkstaTransportAdd(server:'typing.Union[str]',level:'typing.Any',data:'typing.Any') -> 'None':
    """
    binds the redirector to a transport

Args:

      server(typing.Union[str]):The name of the server, or None.
      level(typing.Any):The information level contained in the data
      data(typing.Any):A dictionary holding the share data.Win32 API References

Returns:

      None
        
    """
    pass
        

def NetWkstaTransportDel(server:'typing.Union[str]',TransportName:'typing.Union[str]',ucond:'typing.Any'=0) -> 'None':
    """
    unbinds the transport protocol from redirector

Args:

      server(typing.Union[str]):The name of the server, or None.
      TransportName(typing.Union[str]):The name of the transport to delete.
      ucond(typing.Any):Level of force to use. Can be USE_FORCE or USE_NOFORCE or USE_LOTS_OF_FORCEWin32 API References

Returns:

      None
        
    """
    pass
        

def NetServerDiskEnum(server:'typing.Union[str]',level:'typing.Any') -> 'typing.Any':
    """
    Retrieves the list of disk drives on a server.

Args:

      server(typing.Union[str]):The name of the server to execute on, or None.
      level(typing.Any):The level of data required. Must be 0.Win32 API References

Returns:

      typing.Any:Search for NetServerDiskEnum at msdn, google or google groups.
Return ValueThe result is a list of drives on the server

        
    """
    pass
        

def NetUseAdd(server:'typing.Union[str]',level:'typing.Any',data:'typing.Any') -> 'None':
    """
    Establishes connection between local or NULL device name and a shared resource through 

redirector

Args:

      server(typing.Union[str]):The name of the server, or None.
      level(typing.Any):The information level contained in the data
      data(typing.Any):A dictionary holding the share data in the format of PyUSE_INFO_*.Win32 API References

Returns:

      None
        
    """
    pass
        

def NetUseDel(server:'typing.Union[str]',useName:'typing.Union[str]',forceCond:'typing.Any'=0) -> 'None':
    """
    Ends connection to a shared resource.

Args:

      server(typing.Union[str]):The name of the server, or None.
      useName(typing.Union[str]):The share name
      forceCond(typing.Any):Level of force to use. Can be USE_FORCE or USE_NOFORCE or USE_LOTS_OF_FORCEWin32 API References

Returns:

      None
        
    """
    pass
        

def NetUseEnum(server:'typing.Union[str]',level:'typing.Any',prefLen:'typing.Any',resumeHandle:'typing.Any'=0) -> 'typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any]':
    """
    Retrieves information about transport protocols that 

are currently managed by the redirector

Args:

      server(typing.Union[str]):The name of the server to execute on, or None.
      level(typing.Any):The level of data required. Currently levels 0, 1 and 2 are supported.
      prefLen(typing.Any):The preferred length of the data buffer.Win32 API References
      resumeHandle(typing.Any):A resume handle.  See the return description for more information.

Returns:

      typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any]:Search for NetUseEnum at msdn, google or google groups.
Return ValueThe result is a list of items read (with each item being a dictionary of format 

PyUSE_INFO_*, depending on the level parameter), 

the total available, and a new "resume handle".  The first time you call 

this function, you should pass zero for the resume handle.  If more data 

is available than what was returned, a new non-zero resume handle will be 

returned, which can be used to call the function again to fetch more data. 

This process may repeat, each time with a new resume handle, until zero is 

returned for the new handle, indicating all the data has been read.

        
    """
    pass
        

def NetUseGetInfo(server:'typing.Union[str]',usename:'typing.Union[str]',level:'typing.Any'=0) -> 'typing.Any':
    """
    Retrieves information about the configuration elements for a workstation

Args:

      server(typing.Union[str]):The name of the server to execute on, or None.
      usename(typing.Union[str]):The name of the locally mapped resource.
      level(typing.Any):The information level contained in the data. NOTE: levels 302 and 402 don't seem to work correctly. They return error 124. So currently these info levels are not available.Win32 API References

Returns:

      typing.Any:Search for NetUseGetInfo at msdn, google or google groups.
Return ValueThe result will be a dictionary in one of the PyUSE_INFO_* 

formats, depending on the level parameter.

        
    """
    pass
        

def NetGetAnyDCName(server:'str'=None,domain:'str'=None) -> 'str':
    """
    Returns the name of any domain controller trusted by the specified 

server.

Args:

      server(str):Specifies the name of the remote server on which the function is to execute. If this parameter is None, the local computer is used.
      domain(str):Specifies the name of the domain. If this parameter is None, the name of the domain controller for the primary domain is used.

Returns:

      str
        
    """
    pass
        

def NetGetDCName(server:'str'=None,domain:'str'=None) -> 'str':
    """
    Returns the name of the primary domain controller (PDC).

Args:

      server(str):Specifies the name of the remote server on which the function is to execute. If this parameter is None, the local computer is used.
      domain(str):Specifies the name of the domain. If this parameter is None, the name of the domain controller for the primary domain is used.

Returns:

      str
        
    """
    pass
        

def NetSessionEnum(level:'typing.Any',server:'typing.Union[str]'=None,client:'typing.Union[str]'=None,username:'typing.Union[str]'=None) -> 'typing.Tuple[typing.Any, ...]':
    """
    Returns network sessions for a server, limited to single client and/or 

user if specified.

Args:

      level(typing.Any):Level of information requested, currently accepts 0, 1, 2, 10, and 502
      server(typing.Union[str]):The name of the server for which to list sessions, local machine assumed if None
      client(typing.Union[str]):Name of client computer, or None to list all computer sessions
      username(typing.Union[str]):User name, or None to list all connected usersReturn ValueReturns a sequence of dictionaries representing SESSION_INFO_* structs, depending on level specified

Returns:

      typing.Tuple[typing.Any, ...]:User name, or None to list all connected users
Return ValueReturns a sequence of dictionaries representing SESSION_INFO_* structs, depending on level specified

        
    """
    pass
        

def NetSessionDel(server:'typing.Union[str]',client:'typing.Union[str]'=None,username:'typing.Union[str]'=None) -> 'None':
    """
    Disconnects network connections on a server

Args:

      server(typing.Union[str]):The name of the server on which to operate, local machine assumed if None or blank
      client(typing.Union[str]):Name of client computer, or None
      username(typing.Union[str]):User name, or None for all connected usersReturn ValueReturns None on success

Returns:

      None:User name, or None for all connected users
Return ValueReturns None on success

        
    """
    pass
        

def NetSessionGetInfo(level:'typing.Any',server:'typing.Union[str]',client:'typing.Union[str]',username:'typing.Union[str]') -> 'typing.Any':
    """
    Returns information for a network session from specified client

Args:

      level(typing.Any):Level of information requested, currently accepts 0, 1, 2, 10, and 502
      server(typing.Union[str]):The name of the server on which to operate, None or blank assumes local machine
      client(typing.Union[str]):Name of client computer
      username(typing.Union[str]):User that established sessionReturn ValueReturns a dictionary representing a SESSION_INFO_* struct, depending on level specified

Returns:

      typing.Any:User that established sessionReturn ValueReturns a dictionary representing a SESSION_INFO_* struct, depending on level specified

        
    """
    pass
        

def NetFileEnum(level:'typing.Any',servername:'typing.Union[str]'=None,basepath:'typing.Union[str]'=None,username:'typing.Union[str]'=None) -> 'typing.Tuple[typing.Any, ...]':
    """
    Lists remotely opened resources on a server

Args:

      level(typing.Any):Level of information, 2 or 3 supported
      servername(typing.Union[str]):The name of the server for which to list open resources, local machine assumed if None
      basepath(typing.Union[str]):If specified, limits returned list to files on given path
      username(typing.Union[str]):User that opened resource, or None to list open files for all usersReturn ValueReturns a sequence of dictionaries representing FILE_INFO_* structs, depending on level specified

Returns:

      typing.Tuple[typing.Any, ...]:User that opened resource, or None to list open files for all users
Return ValueReturns a sequence of dictionaries representing FILE_INFO_* structs, depending on level specified

        
    """
    pass
        

def NetFileClose(servername:'typing.Union[str]',fileid:'typing.Any') -> 'None':
    """
    Closes an open network resource on a server

Args:

      servername(typing.Union[str]):Name of server on which to operate, local machine assumed if None
      fileid(typing.Any):Id of opened resource, as returned by win32net::NetFileEnum

Returns:

      None
        
    """
    pass
        

def NetFileGetInfo(level:'typing.Any',servername:'typing.Union[str]',fileid:'typing.Any') -> 'typing.Any':
    """
    Returns information about an open network resource

Args:

      level(typing.Any):Level of information to return, 2 or 3 supported
      servername(typing.Union[str]):Server on which resource is open, local machine assumed if None
      fileid(typing.Any):Id of opened resource, as returned by win32net::NetFileEnum

Returns:

      typing.Any
        
    """
    pass
        

def NetStatisticsGet(server:'typing.Union[str]',service:'typing.Union[str]',level:'typing.Any',options:'typing.Any') -> 'typing.Any':
    """
    Retrieves network statistics for specified service on specified machine

Args:

      server(typing.Union[str]):Name of server/workstation to retrieve statistics for (None or blank uses local).
      service(typing.Union[str]):SERVICE_SERVER or SERVICE_WORKSTATION
      level(typing.Any):Only 0 currently supported.
      options(typing.Any):Must be zero.Return ValueThe result is a dictionary representing a STAT_SERVER_0 or STAT_WORKSTATION_0 struct

Returns:

      typing.Any:Must be zero.Return ValueThe result is a dictionary representing a STAT_SERVER_0 or STAT_WORKSTATION_0 struct

        
    """
    pass
        

def NetServerComputerNameAdd(ServerName:'typing.Union[str]',EmulatedDomainName:'typing.Union[str]',EmulatedServerName:'typing.Union[str]') -> 'None':
    """
    Adds an additional network name for a server

Args:

      ServerName(typing.Union[str]):Name of server that will receive additional name
      EmulatedDomainName(typing.Union[str]):Domain under which to add the new server name, can be None
      EmulatedServerName(typing.Union[str]):New network name that server will respond toReturn ValueReturns none on success

Returns:

      None:New network name that server will respond toReturn ValueReturns none on success

        
    """
    pass
        

def NetServerComputerNameDel(ServerName:'typing.Union[str]',EmulatedServerName:'typing.Union[str]') -> 'None':
    """
    None

Args:

      ServerName(typing.Union[str]):Name of server on which to operate
      EmulatedServerName(typing.Union[str]):Network name to be removedReturn ValueReturns none on success

Returns:

      None:Network name to be removedReturn ValueReturns none on success

        
    """
    pass
        

def NetValidateName(Server:'typing.Union[str]',Name:'typing.Union[str]',NameType:'typing.Any',Account:'typing.Union[str]'=None,Password:'typing.Union[str]'=None) -> 'None':
    """
    Checks that domain/machine/workgroup name is valid for given context

Args:

      Server(typing.Union[str]):Name of server on which to execute (None or blank uses local)
      Name(typing.Union[str]):Machine, domain, or workgroup name to validate
      NameType(typing.Any):Type of name to validate - from NETSETUP_NAME_TYPE enum (win32net.NetSetup*)
      Account(typing.Union[str]):Account name to use while validating, current security context is used if not specified
      Password(typing.Union[str]):Password for AccountCommentsIf Account and Password aren't passed, current logon credentials are usedWill raise NotImplementedError if not available on this platform.Return ValueReturns none if valid, exception if not

Returns:

      None:Password for Account
Comments

If Account and Password aren't passed, current logon credentials are used

Will raise NotImplementedError if not available on this platform.
Return ValueReturns none if valid, exception if not

        
    """
    pass
        

def NetValidatePasswordPolicy(Server:'typing.Union[str]',Qualifier:'typing.Any',ValidationType:'typing.Any',arg:'typing.Union[typing.Any]') -> 'None':
    """
    Allows an application to check 

password compliance against an application-provided account database and 

verify that passwords meet the complexity, aging, minimum length, and 

history reuse requirements of a password policy.

Args:

      Server(typing.Union[str]):Name of server on which to execute (None or blank uses local)
      Qualifier(typing.Any):Reserved, must be None
      ValidationType(typing.Any):The type of password validation to perform
      arg(typing.Union[typing.Any]):Depends on the ValidationType param - either a PyNET_VALIDATE_AUTHENTICATION_INPUT_ARG,  PyNET_VALIDATE_PASSWORD_CHANGE_INPUT_ARG or PyNET_VALIDATE_PASSWORD_RESET_INPUT_ARG tuple or dict.CommentsWill raise NotImplementedError if not available on this platform, or raise win32net.error if the function fails.Return ValueReturns a tuple of (PyNET_VALIDATE_PERSISTED_FIELDS, int) with the integer being the ValidationResult.

Returns:

      None:Depends on the ValidationType param - either 

a PyNET_VALIDATE_AUTHENTICATION_INPUT_ARG,  PyNET_VALIDATE_PASSWORD_CHANGE_INPUT_ARG 

or PyNET_VALIDATE_PASSWORD_RESET_INPUT_ARG

 tuple or dict.Comments

Will raise NotImplementedError if not available on this platform, or 

raise win32net.error if the function fails.
Return ValueReturns a tuple of (PyNET_VALIDATE_PERSISTED_FIELDS, int) with 

the integer being the ValidationResult.

        
    """
    pass
        


__all__=['', 'CryptProtectData', 'CryptUnprotectData', 'CryptEnumProviders', 'CryptEnumProviderTypes', 'CryptGetDefaultProvider', 'CryptSetProviderEx', 'CryptAcquireContext', 'CryptFindLocalizedName', 'CertEnumSystemStore', 'CertEnumSystemStoreLocation', 'CertEnumPhysicalStore', 'CertRegisterSystemStore', 'CertUnregisterSystemStore', 'CertOpenStore', 'CertOpenSystemStore', 'CryptFindOIDInfo', 'CertAlgIdToOID', 'CertOIDToAlgId', 'CryptGetKeyIdentifierProperty', 'CryptEnumKeyIdentifierProperties', 'CryptEnumOIDInfo', 'CertAddSerializedElementToStore', 'CryptQueryObject', 'CryptDecodeMessage', 'CryptEncryptMessage', 'CryptDecryptMessage', 'CryptSignAndEncryptMessage', 'CryptVerifyMessageSignature', 'CryptGetMessageCertificates', 'CryptGetMessageSignerCount', 'CryptSignMessage', 'CryptVerifyDetachedMessageSignature', 'CryptDecryptAndVerifyMessageSignature', 'CryptEncodeObjectEx', 'CryptDecodeObjectEx', 'CertNameToStr', 'CryptFormatObject', 'PFXImportCertStore', 'PFXVerifyPassword', 'PFXIsPFXBlob', 'CryptBinaryToString', 'CryptStringToBinary']
import typing
import win32typing
"""An interface to the win32 Cryptography API"""


def CryptProtectData(DataIn:'typing.Any',DataDescr:'str'=None,OptionalEntropy:'typing.Any'=None,Reserved:'typing.Any'=None,PromptStruct:'win32typing.PyCRYPTPROTECT_PROMPTSTRUCT'=None,Flags:'typing.Any'=0) -> 'typing.Any':
    """
    Encrypts data using a session key derived from current user's logon 

credentials

Args:

      DataIn(typing.Any):Data to be encrypted.
      DataDescr(str):Description to add to the data
      OptionalEntropy(typing.Any):Extra entropy (eg password) for encryption process, can be None
      Reserved(typing.Any):Must be None
      PromptStruct(win32typing.PyCRYPTPROTECT_PROMPTSTRUCT):Contains options for UI display during encryption and decryption, can be None
      Flags(typing.Any):Combination of CRYPTPROTECT_* flags

Returns:

      typing.Any
        
    """
    pass
        

def CryptUnprotectData(DataIn:'typing.Any',OptionalEntropy:'typing.Any'=None,Reserved:'typing.Any'=None,PromptStruct:'win32typing.PyCRYPTPROTECT_PROMPTSTRUCT'=None,Flags:'typing.Any'=0) -> 'typing.Tuple[typing.Any, typing.Any]':
    """
    None

Args:

      DataIn(typing.Any):Data to be decrypted.
      OptionalEntropy(typing.Any):Extra entropy passed to CryptProtectData
      Reserved(typing.Any):Must be None
      PromptStruct(win32typing.PyCRYPTPROTECT_PROMPTSTRUCT):Contains options for UI display during encryption and decryption, can be None
      Flags(typing.Any):Combination of CRYPTPROTECT_* flagsReturn ValueThe result is a tuple of (description, data) where description is the description that was passed to win32crypt::CryptProtectData, and data is the unencrypted data.

Returns:

      typing.Tuple[typing.Any, typing.Any]:Combination of CRYPTPROTECT_* flags
Return ValueThe result is a tuple of (description, data) where description 

is the description that was passed to win32crypt::CryptProtectData, and 

data is the unencrypted data.

        
    """
    pass
        

def CryptEnumProviders() -> 'typing.List[typing.Tuple[str, typing.Any]]':
    """
    List cryptography providers

Args:



Returns:

      typing.List[typing.Tuple[str, typing.Any]]:win32crypt.CryptEnumProviders

[(PyUnicode,int),...] = CryptEnumProviders()List cryptography providers
Return ValueReturns a sequence of tuples containing provider name and type

        
    """
    pass
        

def CryptEnumProviderTypes() -> 'typing.List[typing.Tuple[str, typing.Any]]':
    """
    Lists available local cryptographic provider 

types

Args:



Returns:

      typing.List[typing.Tuple[str, typing.Any]]:win32crypt.CryptEnumProviderTypes

[(PyUnicode,int),...] = CryptEnumProviderTypes()Lists available local cryptographic provider 

types
Comments

Windows XP sp3 has a bug that causes this function to always fail with ERROR_MORE_DATA (234) 

See KB959160 for a hotfix
Return ValueReturns a sequence of tuples containing name and identifier of provider types

        
    """
    pass
        

def CryptGetDefaultProvider(ProvType:'typing.Any',Flags:'typing.Any') -> 'str':
    """
    Returns default provider for local machine or current user

Args:

      ProvType(typing.Any):Type of provider (PROV_* constant)
      Flags(typing.Any):CRYPT_MACHINE_DEFAULT or CRYPT_USER_DEFAULT

Returns:

      str
        
    """
    pass
        

def CryptSetProviderEx(ProvName:'str',ProvType:'typing.Any',Flags:'typing.Any') -> 'None':
    """
    Sets default provider (for machine or user) for specified type

Args:

      ProvName(str):Name of new default provider (MS_*_PROV value)
      ProvType(typing.Any):One of the PROV_* provider types
      Flags(typing.Any):CRYPT_MACHINE_DEFAULT or CRYPT_USER_DEFAULT.  Combine with CRYPT_DELETE_DEFAULT to remove default.

Returns:

      None
        
    """
    pass
        

def CryptAcquireContext(Container:'str',Provider:'str',ProvType:'typing.Any',Flags:'typing.Any') -> 'win32typing.PyCRYPTPROV':
    """
    Retrieve handle to a cryptographic service provider

Args:

      Container(str):Name of key container, can be none to use a Provider's default key container (usually username)
      Provider(str):Name of cryptographic provider. (MS_*_PROV) Use None for user's default provider.
      ProvType(typing.Any):One of the PROV_* constants
      Flags(typing.Any):Combination of CRYPT_VERIFYCONTEXT,CRYPT_NEWKEYSET,CRYPT_MACHINE_KEYSET,CRYPT_DELETEKEYSET,CRYPT_SILENTReturn ValueReturns None if CRYPT_DELETEKEYSET is specified, otherwise returns a handle to the provider

Returns:

      win32typing.PyCRYPTPROV:Combination of 

CRYPT_VERIFYCONTEXT,CRYPT_NEWKEYSET,CRYPT_MACHINE_KEYSET,CRYPT_DELETEKEYSET,CRYPT_SILENTReturn ValueReturns None if CRYPT_DELETEKEYSET is specified, otherwise returns a handle to the provider

        
    """
    pass
        

def CryptFindLocalizedName(CryptName:'str') -> 'str':
    """
    Returns localized name for predefined system stores (Root, 

My, .Default, .LocalMachine)

Args:

      CryptName(str):Name of a system store

Returns:

      str
        
    """
    pass
        

def CertEnumSystemStore(dwFlags:'typing.Any',pvSystemStoreLocationPara:'typing.Any'=None) -> 'typing.List[typing.Any]':
    """
    Lists system stores

Args:

      dwFlags(typing.Any):CERT_SYSTEM_STORE_* location, can be combined with CERT_SYSTEM_STORE_RELOCATE_FLAG
      pvSystemStoreLocationPara(typing.Any):Optional If flags contains CERT_SYSTEM_STORE_RELOCATE_FLAG must be a sequence (PyHkey, unicode) representing a CERT_SYSTEM_STORE_RELOCATE_PARA, otherwise should be a unicode store name

Returns:

      typing.List[typing.Any]
        
    """
    pass
        

def CertEnumSystemStoreLocation(Flags:'typing.Any'=0) -> 'typing.List[typing.Any]':
    """
    Lists system store locations

Args:

      Flags(typing.Any):Reserved, must be 0 if passed in

Returns:

      typing.List[typing.Any]
        
    """
    pass
        

def CertEnumPhysicalStore(pvSystemStore:'str',dwFlags:'typing.Any') -> 'typing.List[typing.Any]':
    """
    Lists physical stores on computer

Args:

      pvSystemStore(str):Name of system store to enumerate physical locations for
      dwFlags(typing.Any):CERT_SYSTEM_STORE_* constant, CERT_SYSTEM_STORE_RELOCATE_FLAG  not supported yet

Returns:

      typing.List[typing.Any]
        
    """
    pass
        

def CertRegisterSystemStore(SystemStore:'str',Flags:'typing.Any') -> 'None':
    """
    Registers a certificate store

Args:

      SystemStore(str):string/unicode name of store to be registered, or a sequence of (PyHkey, unicode) representing a CERT_SYSTEM_STORE_RELOCATE_PARA struct
      Flags(typing.Any):One of the CERT_SYSTEM_STORE_* location constants, can also be combined with CERT_SYSTEM_STORE_RELOCATE_FLAG and CERT_STORE_CREATE_NEW_FLAG

Returns:

      None
        
    """
    pass
        

def CertUnregisterSystemStore(SystemStore:'str',Flags:'typing.Any') -> 'None':
    """
    Unregisters a certificate store

Args:

      SystemStore(str):Name of System store to be unregistered
      Flags(typing.Any):CERT_SYSTEM_STORE_RELOCATE_FLAG, CERT_STORE_DELETE_FLAG (CERT_SYSTEM_STORE_RELOCATE_FLAG  not supported yet)

Returns:

      None
        
    """
    pass
        

def CertOpenStore(StoreProvider:'typing.Any',MsgAndCertEncodingType:'typing.Any',CryptProv:'win32typing.PyCRYPTPROV',Flags:'typing.Any',Para:'typing.Any'=None) -> 'win32typing.PyCERTSTORE':
    """
    Opens a certificate store

Args:

      StoreProvider(typing.Any):CERT_STORE_PROV_*, currently does not accept string provider names
      MsgAndCertEncodingType(typing.Any):Only used with CERT_STORE_PROV_MSG, CERT_STORE_PROV_PKCS7, and CERT_STORE_PROV_FILENAME. Usually should be X509_ASN_ENCODING combined with PKCS_7_ASN_ENCODING
      CryptProv(win32typing.PyCRYPTPROV):Handle to a CSP, can be None to use default provider
      Flags(typing.Any):Combination of CERT_STORE_*_FLAG flags
      Para(typing.Any):PyCERT_SYSTEM_STORE_RELOCATE_PARA, or data specific to provider

Returns:

      win32typing.PyCERTSTORE
        
    """
    pass
        

def CertOpenSystemStore(SubsystemProtocol:'str',Prov:'win32typing.PyCRYPTPROV'=None) -> 'win32typing.PyCERTSTORE':
    """
    Opens most commonly used Certificate Stores

Args:

      SubsystemProtocol(str):Name of store to open, will be created if it doesn't already exist
      Prov(win32typing.PyCRYPTPROV):Handle to CSP, use None for default provider

Returns:

      win32typing.PyCERTSTORE
        
    """
    pass
        

def CryptFindOIDInfo(KeyType:'typing.Any',Key:'typing.Any',GroupId:'typing.Any'=0) -> 'typing.Any':
    """
    Returns information about an algorithm identifier or object identifier

Args:

      KeyType(typing.Any):One of CRYPT_OID_INFO_OID_KEY,CRYPT_OID_INFO_NAME_KEY,CRYPT_OID_INFO_ALGID_KEY,CRYPT_OID_INFO_SIGN_KEY
      Key(typing.Any):Type is dependent on KeyType
      GroupId(typing.Any):CRYPT_*_GROUP_ID constant, or 0Return ValueReturns a dictionary of CRYPT_OID_INFO dataKeyTypeType of KeyCRYPT_OID_INFO_OID_KEYAn szOID_* character stringCRYPT_OID_INFO_NAME_KEYA unicode nameCRYPT_OID_INFO_ALGID_KEYAn ALG_ID, one of the CALG_* integer constantsCRYPT_OID_INFO_SIGN_KEYA tuple of 2 CALG_* integers (hash algorithm, public key algorithm)

Returns:

      typing.Any:CRYPT_*_GROUP_ID constant, or 0
Return ValueReturns a dictionary of CRYPT_OID_INFO data



KeyType


Type of Key



CRYPT_OID_INFO_OID_KEYAn szOID_* character string
CRYPT_OID_INFO_NAME_KEYA unicode name
CRYPT_OID_INFO_ALGID_KEYAn ALG_ID, one of the CALG_* integer constants
CRYPT_OID_INFO_SIGN_KEYA tuple of 2 CALG_* integers (hash algorithm, public key algorithm)

        
    """
    pass
        

def CertAlgIdToOID(AlgId:'typing.Any') -> 'str':
    """
    Converts an integer ALG_ID to it's szOID_ string representation

Args:

      AlgId(typing.Any):An algorithm identifierCommentsIf there is no corresponding OID, None is returned

Returns:

      str
        
    """
    pass
        

def CertOIDToAlgId(ObjId:'str') -> 'typing.Any':
    """
    Converts a string object identfier to a numeric algorith identifier

Args:

      ObjId(str):String szOID_* identifierCommentsIf no matching ALG_ID is found, 0 is returned

Returns:

      typing.Any
        
    """
    pass
        

def CryptGetKeyIdentifierProperty(KeyIdentifier:'str',PropId:'typing.Any',Flags:'typing.Any'=0,ComputerName:'str'=None) -> 'typing.Any':
    """
    Retrieves a property from a certificate by its key 

indentifier

Args:

      KeyIdentifier(str):Hash that identifies a certificate key
      PropId(typing.Any):Property identifier, one of the CERT_*_PROP_ID values
      Flags(typing.Any):Use CRYPT_KEYID_MACHINE_FLAG for machine keyset. (CRYPT_KEYID_ALLOC_FLAG is always added to Flags)
      ComputerName(str):Name of remote computer, use None for local machineCommentsCERT_KEY_PROV_INFO_PROP_ID is only property currently supported

Returns:

      typing.Any
        
    """
    pass
        

def CryptEnumKeyIdentifierProperties(KeyIdentifier:'str'=None,PropId:'typing.Any'=0,Flags:'typing.Any'=0,ComputerName:'str'=None) -> 'typing.Any':
    """
    Enumerates private keys for certificates and their 

properties

Args:

      KeyIdentifier(str):Id of a certificate key, can be None for all keys
      PropId(typing.Any):CERT_*_PROP_ID constant. Limits returned values to specified propery, Use 0 for all
      Flags(typing.Any):Can be CRYPT_KEYID_MACHINE_FLAG to list keys for local machine, or remote machine if ComputerName is given
      ComputerName(str):Name of remote computer, use None for local machine

Returns:

      typing.Any
        
    """
    pass
        

def CryptEnumOIDInfo(GroupId:'typing.Any'=0) -> 'typing.Any':
    """
    Lists registered Object Identifiers that belong to specified group

Args:

      GroupId(typing.Any):The type of OIDs to enmerate, one of the CRYPT_*_OID_GROUP_ID constants or 0 to list all

Returns:

      typing.Any
        
    """
    pass
        

def CertAddSerializedElementToStore(CertStore:'win32typing.PyCERTSTORE',Element:'typing.Any',AddDisposition:'typing.Any',ContextTypeFlags:'typing.Any',Flags:'typing.Any'=0) -> 'win32typing.PyCERT_CONTEXT':
    """
    Imports a serialized Certificate context, 

CRL, or CTL

Args:

      CertStore(win32typing.PyCERTSTORE):Certificate Store to which the context will be added, can be None
      Element(typing.Any):Serialized data
      AddDisposition(typing.Any):one of CERT_STORE_ADD_* values
      ContextTypeFlags(typing.Any):One of CERT_STORE_*_CONTEXT_FLAG constants
      Flags(typing.Any):Reserved, use only 0CommentsCurrently only Certificate contexts are supported

Returns:

      win32typing.PyCERT_CONTEXT
        
    """
    pass
        

def CryptQueryObject(ObjectType:'typing.Any',Object:'typing.Any',ExpectedContentTypeFlags:'typing.Any',ExpectedFormatTypeFlags:'typing.Any',Flags:'typing.Any'=0) -> 'typing.Any':
    """
    Determines the cryptographic type of input data

Args:

      ObjectType(typing.Any):Type of input, CERT_QUERY_OBJECT_BLOB or CERT_QUERY_OBJECT_FILE
      Object(typing.Any):Raw data or a filename containing the data to be queried depending on ObjectType
      ExpectedContentTypeFlags(typing.Any):One of the CERT_QUERY_CONTENT_FLAG_* constants
      ExpectedFormatTypeFlags(typing.Any):One of the CERT_QUERY_FORMAT_FLAG_* constants
      Flags(typing.Any):Reserved, use only 0Return ValueReturns a dictionary containing {MsgAndCertEncodingType:int,	## encoding type, usually X509_ASN_ENCODING combined with PKCS_7_ASN_ENCODING ContentType:int,				## One of the CERT_QUERY_CONTENT_* constants FormatType:int,					## One of the CERT_QUERY_FORMAT_* constants CertStore:PyCERTSTORE,		## Handle to certificate store containing all certficates in the object, may be None 	Msg:PyCRYPTMSG,				## If input doesn't contains a PKCS7 message, will be None Context:PyCERT_CONTEXT}		## A certificate, CRL, or CTL context depending on ContentType, may be None

Returns:

      typing.Any:Reserved, use only 0
Return ValueReturns a dictionary containing 

{MsgAndCertEncodingType:int,	## encoding type, usually X509_ASN_ENCODING combined with PKCS_7_ASN_ENCODING 

ContentType:int,				## One of the CERT_QUERY_CONTENT_* constants 

FormatType:int,					## One of the CERT_QUERY_FORMAT_* constants 

CertStore:PyCERTSTORE,		## Handle to certificate store containing all certficates in the object, may be 

None 	Msg:PyCRYPTMSG,				## If input doesn't contains a PKCS7 message, will be None 

Context:PyCERT_CONTEXT}		## A certificate, CRL, or CTL context depending on ContentType, may be None

        
    """
    pass
        

def CryptDecodeMessage(EncodedBlob:'typing.Any',DecryptPara:'typing.Any',MsgTypeFlags:'typing.Any',VerifyPara:'typing.Any'=None,SignerIndex:'typing.Any'=0,PrevInnerContentType:'typing.Any'=0,ReturnData:'typing.Any'=True) -> 'typing.Any':
    """
    Decodes and decrypts a message, and verifies its signatures

Args:

      EncodedBlob(typing.Any):Data to be decoded
      DecryptPara(typing.Any):PyCRYPT_DECRYPT_MESSAGE_PARA containing decryption parms
      MsgTypeFlags(typing.Any):Combination of CMSG_DATA_FLAG, CMSG_SIGNED_FLAG, CMSG_ENVELOPED_FLAG, CMSG_SIGNED_AND_ENVELOPED_FLAG, or CMSG_HASHED_FLAG
      VerifyPara(typing.Any):PyCRYPT_VERIFY_MESSAGE_PARA containing signature verification parms
      SignerIndex(typing.Any):Index of the signer to verify,  ignored if message is not signed.
      PrevInnerContentType(typing.Any):Content type returned from previous call, used during subsequent pass on a nested message
      ReturnData(typing.Any):Indicates if decoded data should be returned.CommentsOnly one level of encoding is interpreted.  Some types of messages will need multiple calls to completely decode. For example, to decode a message created by win32crypt::CryptSignAndEncryptMessage, one pass with CMSG_ENVELOPED_FLAG 	and a second pass using CMSG_SIGNED_FLAG are required to recover the original message text.Return ValueOutput params are returned as a dict containing: {MsgType:int},					&nbsp&nbsp##Type of message decoded, one of CMSG_DATA,CMSG_SIGNED,CMSG_ENVELOPED,CMSG_SIGNED_AND_ENVELOPED,CMSG_HASHED 	InnerContentType:int, &nbsp&nbsp##Type of decoded content returned, uses same set of values as MsgType.  CMSG_DATA indicates unencoded data. Decoded:str,					&nbsp&nbsp##The decoded data, will be None if ReturnData is False. XchgCert:PyCERT_CONTEXT,	&nbsp&nbsp##Certificate used to decode message SignerCert:PyCERT_CONTEXT}	&nbsp&nbsp##Certificate used to sign message

Returns:

      typing.Any:Indicates if decoded data should be returned.
Comments

Only one level of encoding is interpreted.  Some types of messages will need multiple calls to completely 

decode. 

For example, to decode a message created by win32crypt::CryptSignAndEncryptMessage, one pass with 

CMSG_ENVELOPED_FLAG 	and a second pass using CMSG_SIGNED_FLAG are required to recover the original message text.
Return ValueOutput params are returned as a dict containing: 

{MsgType:int},					&nbsp&nbsp##Type of message decoded, one of 

CMSG_DATA,CMSG_SIGNED,CMSG_ENVELOPED,CMSG_SIGNED_AND_ENVELOPED,CMSG_HASHED 	InnerContentType:int, 

&nbsp&nbsp##Type of decoded content returned, uses same set of values as MsgType.  CMSG_DATA indicates unencoded data. 

Decoded:str,					&nbsp&nbsp##The decoded data, will be None if ReturnData is False. 

XchgCert:PyCERT_CONTEXT,	&nbsp&nbsp##Certificate used to decode message 

SignerCert:PyCERT_CONTEXT}	&nbsp&nbsp##Certificate used to sign message

        
    """
    pass
        

def CryptEncryptMessage(EncryptPara:'win32typing.PyCRYPT_ENCRYPT_MESSAGE_PARA',RecipientCert:'typing.Tuple[win32typing.PyCERT_CONTEXT, ...]',ToBeEncrypted:'typing.Any') -> 'typing.Any':
    """
    Encrypts and encodes a message

Args:

      EncryptPara(win32typing.PyCRYPT_ENCRYPT_MESSAGE_PARA):Encryption parameters
      RecipientCert(typing.Tuple[win32typing.PyCERT_CONTEXT, ...]):Sequence of handles to recipients' certificates
      ToBeEncrypted(typing.Any):Data to be encrypted

Returns:

      typing.Any
        
    """
    pass
        

def CryptDecryptMessage(DecryptPara:'win32typing.PyCRYPT_DECRYPT_MESSAGE_PARA',EncryptedBlob:'typing.Any') -> 'typing.Tuple[typing.Any, win32typing.PyCERT_CONTEXT]':
    """
    Decrypts an encrypted and encoded message

Args:

      DecryptPara(win32typing.PyCRYPT_DECRYPT_MESSAGE_PARA):Dictionary containing decryption parameters
      EncryptedBlob(typing.Any):Buffer containing an encrypted messageReturn ValueReturns the decrypted message and a handle to the certificate used to decrypt it

Returns:

      typing.Tuple[typing.Any, win32typing.PyCERT_CONTEXT]:Buffer containing an encrypted messageReturn ValueReturns the decrypted message and a handle to the certificate used to decrypt it

        
    """
    pass
        

def CryptSignAndEncryptMessage(SignPara:'win32typing.PyCRYPT_SIGN_MESSAGE_PARA',EncryptPara:'win32typing.PyCRYPT_ENCRYPT_MESSAGE_PARA',RecipientCert:'typing.Tuple[win32typing.PyCERT_CONTEXT, ...]',ToBeSignedAndEncrypted:'typing.Any') -> 'typing.Any':
    """
    Encrypts, encodes and signs a message using a certificate

Args:

      SignPara(win32typing.PyCRYPT_SIGN_MESSAGE_PARA):Message signing parameters
      EncryptPara(win32typing.PyCRYPT_ENCRYPT_MESSAGE_PARA):Encryption parameters
      RecipientCert(typing.Tuple[win32typing.PyCERT_CONTEXT, ...]):Sequence of certificates of intended recipients
      ToBeSignedAndEncrypted(typing.Any):Buffer containing data to be encoded in the message

Returns:

      typing.Any
        
    """
    pass
        

def CryptVerifyMessageSignature(SignedBlob:'typing.Any',SignerIndex:'typing.Any'=0,VerifyPara:'win32typing.PyCRYPT_VERIFY_MESSAGE_PARA'=None,ReturnData:'typing.Any'=False) -> 'typing.Tuple[win32typing.PyCERT_CONTEXT, typing.Any]':
    """
    Verifies the signature of an encoded 

message

Args:

      SignedBlob(typing.Any):Buffer containing a signed message
      SignerIndex(typing.Any):Index of the signer to verify, zero-based
      VerifyPara(win32typing.PyCRYPT_VERIFY_MESSAGE_PARA):Signature verification parameters, use None for defaults
      ReturnData(typing.Any):Indicates if decoded data should be returned.Return ValueReturns the signing certificate and the decoded data.  If ReturnData parm is False, None is returned for data.

Returns:

      typing.Tuple[win32typing.PyCERT_CONTEXT, typing.Any]:Indicates if decoded data should be returned.
Return ValueReturns the signing certificate and the decoded data.  If ReturnData parm is False, None is returned for data.

        
    """
    pass
        

def CryptGetMessageCertificates(SignedBlob:'typing.Any',MsgAndCertEncodingType:'typing.Any',CryptProv:'win32typing.PyCRYPTPROV'=None,Flags:'typing.Any'=0) -> 'win32typing.PyCERTSTORE':
    """
    Extracts certificates encoded in a message

Args:

      SignedBlob(typing.Any):Buffer containing a signed message
      MsgAndCertEncodingType(typing.Any):Message and certificate encoding types
      CryptProv(win32typing.PyCRYPTPROV):Handle to a CSP, use None for default
      Flags(typing.Any):Same flags used with win32crypt::CertOpenStore

Returns:

      win32typing.PyCERTSTORE
        
    """
    pass
        

def CryptGetMessageSignerCount(SignedBlob:'typing.Any',MsgEncodingType:'typing.Any') -> 'typing.Any':
    """
    Finds the number of signers of an encoded message

Args:

      SignedBlob(typing.Any):Buffer containing a signed message
      MsgEncodingType(typing.Any):Message encoding type

Returns:

      typing.Any
        
    """
    pass
        

def CryptSignMessage(SignPara:'win32typing.PyCRYPT_SIGN_MESSAGE_PARA',ToBeSigned:'typing.Tuple[typing.Any, ...]',DetachedSignature:'typing.Any'=False) -> 'typing.Any':
    """
    Signs and encodes a message

Args:

      SignPara(win32typing.PyCRYPT_SIGN_MESSAGE_PARA):Message signing parameters
      ToBeSigned(typing.Tuple[typing.Any, ...]):Sequence of strings containing message data.  Can only contain 1 string if DetachedSignature parm is False.
      DetachedSignature(typing.Any):If True, only the signature itself is encoded in output msg.

Returns:

      typing.Any
        
    """
    pass
        

def CryptVerifyDetachedMessageSignature(SignerIndex:'typing.Any',DetachedSignBlob:'typing.Any',ToBeSigned:'typing.Tuple[typing.Any, ...]',VerifyPara:'win32typing.PyCRYPT_VERIFY_MESSAGE_PARA'=None) -> 'win32typing.PyCERT_CONTEXT':
    """
    Verifies a signature that is encoded 

separately from the data

Args:

      SignerIndex(typing.Any):Index of the signer to verify
      DetachedSignBlob(typing.Any):Buffer containing an encoded signature
      ToBeSigned(typing.Tuple[typing.Any, ...]):Sequence of buffers containing message data.
      VerifyPara(win32typing.PyCRYPT_VERIFY_MESSAGE_PARA):Signature verification parameters, use None for defaultsReturn ValueReturns the signing certificate

Returns:

      win32typing.PyCERT_CONTEXT:Signature verification parameters, use 

None for defaults
Return ValueReturns the signing certificate

        
    """
    pass
        

def CryptDecryptAndVerifyMessageSignature(EncryptedBlob:'typing.Any',DecryptPara:'win32typing.PyCRYPT_DECRYPT_MESSAGE_PARA',VerifyPara:'win32typing.PyCRYPT_VERIFY_MESSAGE_PARA'=None,SignerIndex:'typing.Any'=0) -> 'typing.Any':
    """
    Decrypts and decodes a signed message, and verifies 

its signatures

Args:

      EncryptedBlob(typing.Any):Encoded message to be decrypted.
      DecryptPara(win32typing.PyCRYPT_DECRYPT_MESSAGE_PARA):Decryption parms
      VerifyPara(win32typing.PyCRYPT_VERIFY_MESSAGE_PARA):Signature verification parms
      SignerIndex(typing.Any):Index of the signer to verify, zero-based.CommentsUsage is similar to CryptDecodeMessage, except that it undoes all levels of encoding and returns the bare message.   This function is the counterpart of CryptSignAndEncryptMessage.Return ValueOutput params are returned as a dict containing: Decrypted:str,					&nbsp&nbsp##The decrypted message contents XchgCert:PyCERT_CONTEXT,	&nbsp&nbsp##Certificate whose private key was used to decrypt message SignerCert:PyCERT_CONTEXT	&nbsp&nbsp##Certificate used to sign message

Returns:

      typing.Any:Index of the signer to verify, zero-based.
Comments

Usage is similar to CryptDecodeMessage, except that it undoes all levels of encoding and 

returns the bare message.   This function is the counterpart of CryptSignAndEncryptMessage.
Return ValueOutput params are returned as a dict containing: 

Decrypted:str,					&nbsp&nbsp##The decrypted message contents 

XchgCert:PyCERT_CONTEXT,	&nbsp&nbsp##Certificate whose private key was used to decrypt message 

SignerCert:PyCERT_CONTEXT	&nbsp&nbsp##Certificate used to sign message

        
    """
    pass
        

def CryptEncodeObjectEx(StructType:'typing.Union[typing.Any]',StructInfo:'typing.Any',CertEncodingType:'typing.Any',Flags:'typing.Any'=0,EncodePara:'typing.Any'=None) -> 'typing.Any':
    """
    Serializes and ASN encodes cryptographic structures

Args:

      StructType(typing.Union[typing.Any]):OID identifying type of data to be encoded, either szOID_* string or a numeric id
      StructInfo(typing.Any):Information to be encoded.  Contents of dict are dependent on StructType
      CertEncodingType(typing.Any):Encoding types
      Flags(typing.Any):Encoding options, combination of CRYPT_UNICODE_* constants.  CRYPT_ENCODE_ALLOC_FLAG is added to flags..
      EncodePara(typing.Any):Not supported, use only NoneStructTypeType of inputszOID_ENHANCED_KEY_USAGEPyCTL_USAGE (sequence of OID's)X509_ENHANCED_KEY_USAGEPyCTL_USAGE (sequence of OID's)szOID_KEY_USAGEPyCRYPT_BIT_BLOBX509_KEY_USAGEPyCRYPT_BIT_BLOBX509_BITSPyCRYPT_BIT_BLOB

Returns:

      typing.Any
        
    """
    pass
        

def CryptDecodeObjectEx(StructType:'typing.Union[typing.Any]',Encoded:'typing.Any',CertEncodingType:'typing.Any',Flags:'typing.Any'=0,DecodePara:'typing.Any'=None) -> 'typing.Any':
    """
    Decodes ASN encoded data

Args:

      StructType(typing.Union[typing.Any]):An OID identifying the type of data to be decoded, can be either str or int
      Encoded(typing.Any):String or buffer containing ASN encoded data
      CertEncodingType(typing.Any):Encoding types
      Flags(typing.Any):Encoding options, can be combination CRYPT_UNICODE_* constants.  CRYPT_ENCODE_ALLOC_FLAG is added to flags..
      DecodePara(typing.Any):Not supported, use only NoneOIDObject returnedszOID_ENHANCED_KEY_USAGESequence of OIDsX509_ENHANCED_KEY_USAGESequence of OIDsszOID_KEY_USAGEPyCRYPT_BIT_BLOBX509_KEY_USAGEPyCRYPT_BIT_BLOBX509_BITSPyCRYPT_BIT_BLOBszOID_SUBJECT_ALT_NAMEPyCERT_ALT_NAME_INFOszOID_SUBJECT_ALT_NAME2PyCERT_ALT_NAME_INFOszOID_ISSUER_ALT_NAMEPyCERT_ALT_NAME_INFOszOID_ISSUER_ALT_NAME2PyCERT_ALT_NAME_INFOszOID_NEXT_UPDATE_LOCATIONPyCERT_ALT_NAME_INFOX509_ALTERNATE_NAMEPyCERT_ALT_NAME_INFOX509_NAME_VALUEPyCERT_NAME_VALUEX509_UNICODE_ANY_STRINGPyCERT_NAME_VALUEX509_UNICODE_NAME_VALUEPyCERT_NAME_VALUEX509_NAMEPyCERT_NAME_INFOX509_UNICODE_NAMEPyCERT_NAME_INFOszOID_KEY_ATTRIBUTESPyCERT_KEY_ATTRIBUTES_INFOX509_KEY_ATTRIBUTESPyCERT_KEY_ATTRIBUTES_INFOszOID_BASIC_CONSTRAINTSPyCERT_BASIC_CONSTRAINTS_INFOX509_BASIC_CONSTRAINTSPyCERT_BASIC_CONSTRAINTS_INFOszOID_BASIC_CONSTRAINTS2PyCERT_BASIC_CONSTRAINTS2_INFOX509_BASIC_CONSTRAINTS2PyCERT_BASIC_CONSTRAINTS2_INFOszOID_CERT_POLICIESSequence of PyCERT_POLICY_INFO objectsszOID_APPLICATION_CERT_POLICIESSequence of PyCERT_POLICY_INFO objectsX509_CERT_POLICIESSequence of PyCERT_POLICY_INFO objectsszOID_SUBJECT_KEY_IDENTIFIERBinary string containing the key identifierszOID_AUTHORITY_KEY_IDENTIFIERPyCERT_AUTHORITY_KEY_ID_INFOX509_AUTHORITY_KEY_IDPyCERT_AUTHORITY_KEY_ID_INFOReturn ValueType of object returned is dependent on the StructType to be decoded

Returns:

      typing.Any:Not supported, use only None



OID


Object returned



szOID_ENHANCED_KEY_USAGESequence of OIDs
X509_ENHANCED_KEY_USAGESequence of OIDs
szOID_KEY_USAGEPyCRYPT_BIT_BLOB
X509_KEY_USAGEPyCRYPT_BIT_BLOB
X509_BITSPyCRYPT_BIT_BLOB
szOID_SUBJECT_ALT_NAMEPyCERT_ALT_NAME_INFO
szOID_SUBJECT_ALT_NAME2PyCERT_ALT_NAME_INFO
szOID_ISSUER_ALT_NAMEPyCERT_ALT_NAME_INFO
szOID_ISSUER_ALT_NAME2PyCERT_ALT_NAME_INFO
szOID_NEXT_UPDATE_LOCATIONPyCERT_ALT_NAME_INFO
X509_ALTERNATE_NAMEPyCERT_ALT_NAME_INFO
X509_NAME_VALUEPyCERT_NAME_VALUE
X509_UNICODE_ANY_STRINGPyCERT_NAME_VALUE
X509_UNICODE_NAME_VALUEPyCERT_NAME_VALUE
X509_NAMEPyCERT_NAME_INFO
X509_UNICODE_NAMEPyCERT_NAME_INFO
szOID_KEY_ATTRIBUTESPyCERT_KEY_ATTRIBUTES_INFO
X509_KEY_ATTRIBUTESPyCERT_KEY_ATTRIBUTES_INFO
szOID_BASIC_CONSTRAINTSPyCERT_BASIC_CONSTRAINTS_INFO
X509_BASIC_CONSTRAINTSPyCERT_BASIC_CONSTRAINTS_INFO
szOID_BASIC_CONSTRAINTS2PyCERT_BASIC_CONSTRAINTS2_INFO
X509_BASIC_CONSTRAINTS2PyCERT_BASIC_CONSTRAINTS2_INFO
szOID_CERT_POLICIESSequence of PyCERT_POLICY_INFO objects
szOID_APPLICATION_CERT_POLICIESSequence of PyCERT_POLICY_INFO objects
X509_CERT_POLICIESSequence of PyCERT_POLICY_INFO objects
szOID_SUBJECT_KEY_IDENTIFIERBinary string containing the key identifier
szOID_AUTHORITY_KEY_IDENTIFIERPyCERT_AUTHORITY_KEY_ID_INFO
X509_AUTHORITY_KEY_IDPyCERT_AUTHORITY_KEY_ID_INFO
Return ValueType of object returned is dependent on the StructType to be decoded

        
    """
    pass
        

def CertNameToStr(Name:'typing.Any',StrType:'typing.Any',CertEncodingType:'typing.Any') -> 'typing.Any':
    """
    Converts an encoded CERT_NAME_INFO into a formatted string

Args:

      Name(typing.Any):String containing an encoded CERT_NAME_INFO, as used with certificate Issuer and Subject
      StrType(typing.Any):Type of string to format, one of CERT_SIMPLE_NAME_STR,CERT_OID_NAME_STR,CERT_X500_NAME_STR
      CertEncodingType(typing.Any):Input encodingCommentsUsually this encoded data is contained in a CERT_NAME_BLOB

Returns:

      typing.Any
        
    """
    pass
        

def CryptFormatObject(StructType:'typing.Union[typing.Any]',Encoded:'typing.Any',CertEncodingType:'typing.Any',FormatStrType:'typing.Any'=0,FormatType:'typing.Any'=0,FormatStruct:'typing.Any'=None) -> 'typing.Any':
    """
    Formats an encoded buffer into a readable string

Args:

      StructType(typing.Union[typing.Any]):OID identifying the type of encoded data, one of the szOID_* strings or an integer OID
      Encoded(typing.Any):String containing encoded data to be formatted
      CertEncodingType(typing.Any):Input encoding
      FormatStrType(typing.Any):String formatting options, combination of CRYPT_FORMAT_STR_MULTI_LINE, CRYPT_FORMAT_STR_NO_HEX
      FormatType(typing.Any):Reserved, use only 0
      FormatStruct(typing.Any):Reserved, use only NoneCommentsWill handle all of the common certificate extension typesWin32 API References

Returns:

      typing.Any
        
    """
    pass
        

def PFXImportCertStore(PFX:'typing.Any',Password:'typing.Any',Flags:'typing.Any') -> 'win32typing.PyCERTSTORE':
    """
    Creates a certificate store from PKCS#12 data (*.PFX files)

Args:

      PFX(typing.Any):Buffer containing PKCS#12-formatted certificate(s)
      Password(typing.Any):Password used to encrypt the data, may be None
      Flags(typing.Any):Allowed flags are CRYPT_EXPORTABLE,CRYPT_USER_PROTECTED,CRYPT_MACHINE_KEYSET, and CRYPT_USER_KEYSETCommentsMSDN docs specify that *one* of the Flags can be used, but in practice a combination is allowedDepending on the encrypting application, a blank password ("") may be treated differently that a NULL password (None), so if you have a PFX with no password try both.Win32 API References

Returns:

      win32typing.PyCERTSTORE
        
    """
    pass
        

def PFXVerifyPassword(PFX:'typing.Any',Password:'typing.Any',Flags:'typing.Any') -> 'typing.Any':
    """
    Checks if a PFX blob can be decrypted with given password

Args:

      PFX(typing.Any):Buffer containing PKCS#12-formatted certificate(s)
      Password(typing.Any):Password used to encrypt the data, may be None
      Flags(typing.Any):Allowed flags are CRYPT_EXPORTABLE,CRYPT_USER_PROTECTED,CRYPT_MACHINE_KEYSET, and CRYPT_USER_KEYSETWin32 API References

Returns:

      typing.Any
        
    """
    pass
        

def PFXIsPFXBlob(PFX:'typing.Any') -> 'typing.Any':
    """
    Checks if data buffer contains a PFX blob

Args:

      PFX(typing.Any):Buffer containing data to be checkedWin32 API References

Returns:

      typing.Any
        
    """
    pass
        

def CryptBinaryToString(Binary:'typing.Any',Flags:'typing.Any') -> 'typing.Any':
    """
    Formats a binary buffer into the specified type of string

Args:

      Binary(typing.Any):Buffer containing raw data to be formatted
      Flags(typing.Any):Type of output desired, win32cryptcon.CRYPT_STRING_* valueWin32 API References

Returns:

      typing.Any
        
    """
    pass
        

def CryptStringToBinary(String:'typing.Any',Flags:'typing.Any') -> 'typing.Tuple[typing.Any, typing.Any, typing.Any]':
    """
    Converts a formatted string back into raw bytes

Args:

      String(typing.Any):Formatted string to be converted to raw binary data
      Flags(typing.Any):Input format (win32cryptcon.CRYPT_STRING_*)Win32 API References

Returns:

      typing.Tuple[typing.Any, typing.Any, typing.Any]:Search for CryptStringToBinary at msdn, google or google groups.
Return ValueReturns the decoded binary data, number of header characters skipped, and CRYPT_STRING_* value 

denoting the type of data found (used if input Flags is one of *_ANY values)

        
    """
    pass
        


__all__=['', 'AssocCreate', 'AssocCreateForClasses', 'DragQueryFile', 'DragQueryFileW', 'DragQueryPoint', 'IsUserAnAdmin', 'SHCreateDataObject', 'SHCreateDefaultContextMenu', 'SHCreateDefaultExtractIcon', 'SHCreateShellFolderView', 'SHCreateShellItemArray', 'SHCreateShellItemArrayFromDataObject', 'SHCreateShellItemArrayFromIDLists', 'SHCreateShellItemArrayFromShellItem', 'SHGetPathFromIDList', 'SHGetPathFromIDListW', 'SHBrowseForFolder', 'SHGetFileInfo', 'SHGetFolderPath', 'SHSetFolderPath', 'SHGetFolderLocation', 'SHGetNameFromIDList', 'SHGetSpecialFolderPath', 'SHGetSpecialFolderLocation', 'SHAddToRecentDocs', 'SHChangeNotify', 'SHEmptyRecycleBin', 'SHQueryRecycleBin', 'SHGetDesktopFolder', 'SHUpdateImage', 'SHChangeNotify', 'SHChangeNotifyRegister', 'SHChangeNotifyDeregister', 'SHCreateItemFromIDList', 'SHCreateItemFromParsingName', 'SHCreateItemFromRelativeName', 'SHCreateItemInKnownFolder', 'SHCreateItemWithParent', 'SHGetIDListFromObject', 'SHGetInstanceExplorer', 'SHFileOperation', 'StringAsCIDA', 'CIDAAsString', 'StringAsPIDL', 'AddressAsPIDL', 'PIDLAsString', 'SHGetSettings', 'FILEGROUPDESCRIPTORAsString', 'StringAsFILEGROUPDESCRIPTOR', 'ShellExecuteEx', 'SHGetViewStatePropertyBag', 'SHILCreateFromPath', 'SHCreateShellItem', 'SHOpenFolderAndSelectItems', 'SHCreateStreamOnFileEx', 'SetCurrentProcessExplicitAppUserModelID', 'GetCurrentProcessExplicitAppUserModelID', 'SHParseDisplayName']
import typing
import win32typing
"""A module wrapping Windows Shell functions and interfaces"""


def AssocCreate() -> 'win32typing.PyIQueryAssociations':
    """
    None

Args:



Returns:

      win32typing.PyIQueryAssociations
        
    """
    pass
        

def AssocCreateForClasses() -> 'win32typing.PyIUnknown':
    """
    Retrieves an object that implements an IQueryAssociations 

interface.

Args:



Returns:

      win32typing.PyIUnknown
        
    """
    pass
        

def DragQueryFile(hglobal:'int',index:'typing.Any') -> 'typing.Union[typing.Any, str]':
    """
    Retrieves the names (or count) of dropped files

Args:

      hglobal(int):The HGLOBAL object - generally obtained via the 'data_handle' property of a PySTGMEDIUM object.
      index(typing.Any):The index to retrieve.  If -1, the result if an integer representing the valid index values.

Returns:

      typing.Union[typing.Any, str]
        
    """
    pass
        

def DragQueryFileW(hglobal:'int',index:'typing.Any') -> 'typing.Union[typing.Any, str]':
    """
    Retrieves the names (or count) of dropped files

Args:

      hglobal(int):The HGLOBAL object - generally obtained via the 'data_handle' property of a PySTGMEDIUM object.
      index(typing.Any):The index to retrieve.  If -1, the result if an integer representing the valid index values.

Returns:

      typing.Union[typing.Any, str]
        
    """
    pass
        

def DragQueryPoint(hglobal:'int') -> 'typing.Tuple[typing.Any, typing.Any, typing.Any]':
    """
    Retrieves the position of the mouse pointer at the time a file was 

dropped during a drag-and-drop operation.

Args:

      hglobal(int):The HGLOBAL object - generally obtained the 'data_handle' property of a PySTGMEDIUMCommentsThe window for which coordinates are returned is the window that received the WM_DROPFILES messageReturn ValueThe first item of the return tuple is True if the drop occurred in the client area of the window, or False if the drop did not occur in the client area of the window.

Returns:

      typing.Tuple[typing.Any, typing.Any, typing.Any]:The HGLOBAL object - generally obtained the 

'data_handle' property of a PySTGMEDIUMComments

The window for which coordinates are returned is the window that received the WM_DROPFILES message
Return ValueThe first item of the return tuple is True if the drop occurred in the client area of the window, or False if 

the drop did not occur in the client area of the window.

        
    """
    pass
        

def IsUserAnAdmin() -> 'typing.Any':
    """
    Tests whether the current user is a member of the Administrator's group.

Args:



Returns:

      typing.Any:shell.IsUserAnAdmin

bool = IsUserAnAdmin()Tests whether the current user is a member of the Administrator's group.
Comments

This method is only available with version 5 or later of the shell controls
Return ValueThe result is true or false, or a com_error with E_NOTIMPL is raised.

        
    """
    pass
        

def SHCreateDataObject(parent:'typing.Any',children:'typing.List[typing.Any]',do_inner:'win32typing.PyIDataObject',iid:'win32typing.PyIID') -> 'win32typing.PyIUnknown':
    """
    None

Args:

      parent(typing.Any):
      children(typing.List[typing.Any]):
      do_inner(win32typing.PyIDataObject):The inner data object, or None bNoneOK */))
      iid(win32typing.PyIID):The IID to query forCommentsThis function is only available on Vista and later; a COM exception with E_NOTIMPL will be thrown if the function can't be located.

Returns:

      win32typing.PyIUnknown
        
    """
    pass
        

def SHCreateDefaultContextMenu(dcm:'typing.Any',iid:'win32typing.PyIID') -> 'win32typing.PyIUnknown':
    """
    None

Args:

      dcm(typing.Any):
      iid(win32typing.PyIID):The IID to query forCommentsThis function is only available on Vista and later; a COM exception with E_NOTIMPL will be thrown if the function can't be located.

Returns:

      win32typing.PyIUnknown
        
    """
    pass
        

def SHCreateDefaultExtractIcon() -> 'win32typing.PyIDefaultExtractIconInit':
    """
    Creates a standard icon extractor, whose 

defaults can be further configured via the IDefaultExtractIconInit interface.

Args:



Returns:

      win32typing.PyIDefaultExtractIconInit
        
    """
    pass
        

def SHCreateShellFolderView(sf:'win32typing.PyIShellFolder',viewOuter:'win32typing.PyIShellView'=None,callbacks:'typing.Any'=None) -> 'win32typing.PyIShellView':
    """
    Creates a new instance of the default Shell folder view 

object.

Args:

      sf(win32typing.PyIShellFolder):
      viewOuter(win32typing.PyIShellView):
      callbacks(typing.Any):

Returns:

      win32typing.PyIShellView
        
    """
    pass
        

def SHCreateShellItemArray(parent:'win32typing.PyIDL',sf:'win32typing.PyIShellFolder',children:'typing.List[win32typing.PyIDL]') -> 'win32typing.PyIShellItemArray':
    """
    Creates a Shell item array object.

Args:

      parent(win32typing.PyIDL):Absolute ID list of parent folder, or None if sf is specified
      sf(win32typing.PyIShellFolder):The Shell data source object that is the parent of the child items specified in children. If parent is specified, this parameter can be NULL. bNoneOK */))
      children(typing.List[win32typing.PyIDL]):Sequence of relative IDLs for items in the parent folderCommentsThis function is only available on Vista and later; a COM exception with E_NOTIMPL will be thrown if the function can't be located.

Returns:

      win32typing.PyIShellItemArray
        
    """
    pass
        

def SHCreateShellItemArrayFromDataObject(do:'win32typing.PyIDataObject',iid:'win32typing.PyIID') -> 'win32typing.PyIShellItemArray':
    """
    Creates a shell item array from an 

IDataObject 

interface that contains a list of items (eg CF_HDROP)

Args:

      do(win32typing.PyIDataObject):A data object that can be rendered as a list of items
      iid(win32typing.PyIID):The interface to createCommentsThis function is only available on Vista and later; a COM exception with E_NOTIMPL will be thrown if the function can't be located.

Returns:

      win32typing.PyIShellItemArray
        
    """
    pass
        

def SHCreateShellItemArrayFromIDLists(pidls:'typing.List[win32typing.PyIDL]') -> 'win32typing.PyIShellItemArray':
    """
    Creates a shell item array from a number of 

item identifiers

Args:

      pidls(typing.List[win32typing.PyIDL]):A sequence of absolute IDLs.CommentsThis function is only available on Vista and later; a COM exception with E_NOTIMPL will be thrown if the function can't be located.

Returns:

      win32typing.PyIShellItemArray
        
    """
    pass
        

def SHCreateShellItemArrayFromShellItem(si:'win32typing.PyIShellItem',riid:'win32typing.PyIID') -> 'win32typing.PyIShellItemArray':
    """
    Creates an item array containing a single 

item

Args:

      si(win32typing.PyIShellItem):A shell item bNoneOK */))
      riid(win32typing.PyIID):The interface to returnCommentsThis function is only available on Vista and later; a COM exception with E_NOTIMPL will be thrown if the function can't be located.

Returns:

      win32typing.PyIShellItemArray
        
    """
    pass
        

def SHGetPathFromIDList(idl:'win32typing.PyIDL') -> 'str':
    """
    Converts an IDLIST to a path.

Args:

      idl(win32typing.PyIDL):The ITEMIDLIST

Returns:

      str
        
    """
    pass
        

def SHGetPathFromIDListW(idl:'win32typing.PyIDL') -> 'str':
    """
    Converts an IDLIST to a path.

Args:

      idl(win32typing.PyIDL):The ITEMIDLIST

Returns:

      str
        
    """
    pass
        

def SHBrowseForFolder(hwndOwner:'int'=None,pidlRoot:'win32typing.PyIDL'=None,title:'typing.Union[typing.Any, str]'=None,flags:'typing.Any'=0,callback:'typing.Any'=None,callback_data:'typing.Any'=None) -> 'typing.Tuple[win32typing.PyIDL, typing.Any, typing.Any]':
    """
    Displays a dialog box that enables the user 

to select a shell folder.

Args:

      hwndOwner(int):Parent window for the dialog box, can be None
      pidlRoot(win32typing.PyIDL):PIDL identifying the place to start browsing. Desktop is used if not specified
      title(typing.Union[typing.Any, str]):Title to be displayed with the directory tree
      flags(typing.Any):Combination of shellcon.BIF_* flags
      callback(typing.Any):A callable object to be used as the callback, or None
      callback_data(typing.Any):An object passed to the callback functionCommentsIf you provide a callback function, it should take 4 args: hwnd, msg, lp, data.  Data will be whatever you passed as callback_data, and the rest are integers.  See the Microsoft documentation for SHBrowseForFolder, or the browse_for_folder.py shell sample for more information.Return ValueThe result is ALWAYS a tuple of 3 items.  If the user cancels the dialog, all items are None.  If the dialog is closed normally, the result is a tuple of (PIDL, DisplayName, iImageList)

Returns:

      typing.Tuple[win32typing.PyIDL, typing.Any, typing.Any]:An object passed to the callback function
Comments

If you provide a callback function, it should take 4 args: 

hwnd, msg, lp, data.  Data will be whatever you passed as callback_data, 

and the rest are integers.  See the Microsoft documentation for 

SHBrowseForFolder, or the browse_for_folder.py shell sample for more 

information.
Return ValueThe result is ALWAYS a tuple of 3 items.  If the user cancels the 

dialog, all items are None.  If the dialog is closed normally, the result is 

a tuple of (PIDL, DisplayName, iImageList)

        
    """
    pass
        

def SHGetFileInfo(name:'typing.Union[win32typing.PyIDL, str]',dwFileAttributes:'typing.Any',uFlags:'typing.Any',infoAttrs:'typing.Any'=0) -> 'typing.Tuple[typing.Any, win32typing.SHFILEINFO]':
    """
    Retrieves information about an object in the file system, such as a 

file, a folder, a directory, or a drive root.

Args:

      name(typing.Union[win32typing.PyIDL, str]):The path and file name. Both absolute and relative paths are valid. If the uFlags parameter includes the SHGFI_PIDL flag, this parameter must be a valid PyIDL object that uniquely identifies the file within the shell's namespace. The PIDL must be a fully qualified PIDL. Relative PIDLs are not allowed. If the uFlags parameter includes the SHGFI_USEFILEATTRIBUTES flag, this parameter does not have to be a valid file name. The function will proceed as if the file exists with the specified name and with the file attributes passed in the dwFileAttributes parameter. This allows you to obtain information about a file type by passing just the extension for pszPath and passing FILE_ATTRIBUTE_NORMAL in dwFileAttributes. This string can use either short (the 8.3 form) or long file names.
      dwFileAttributes(typing.Any):Combination of one or more file attribute flags (FILE_ATTRIBUTE_ values). If uFlags does not include the SHGFI_USEFILEATTRIBUTES flag, this parameter is ignored.
      uFlags(typing.Any):Combination of shellcon.SHGFI_* flags that specify the file information to retrieve.  See MSDN for details
      infoAttrs(typing.Any):Flags copied to the SHFILEINFO.dwAttributes member - useful when flags contains SHGFI_ATTR_SPECIFIED

Returns:

      typing.Tuple[typing.Any, win32typing.SHFILEINFO]
        
    """
    pass
        

def SHGetFolderPath(hwndOwner:'int',nFolder:'typing.Any',handle:'int',flags:'typing.Any') -> 'typing.Union[str]':
    """
    Retrieves the path of a folder.

Args:

      hwndOwner(int):Parent window, can be None (or 0)
      nFolder(typing.Any):One of the CSIDL_* constants specifying the path.
      handle(int):An access token that can be used to represent a particular user, or None
      flags(typing.Any):Controls which path is returned.  May be SHGFP_TYPE_CURRENT or SHGFP_TYPE_DEFAULTCommentsThis method is only available with later versions of shell32.dll, or if you have shfolder.dll installed on earlier systems

Returns:

      typing.Union[str]
        
    """
    pass
        

def SHSetFolderPath(csidl:'typing.Any',Path:'typing.Union[typing.Any]',hToken:'int'=None) -> 'None':
    """
    Sets the location of one of the special folders

Args:

      csidl(typing.Any):One of the shellcon.CSIDL_* values
      Path(typing.Union[typing.Any]):The full path to be set
      hToken(int):Handle to an access token, can be NoneCommentsThis function is only available on Windows 2000 or later

Returns:

      None
        
    """
    pass
        

def SHGetFolderLocation(hwndOwner:'typing.Any',nFolder:'typing.Any',hToken:'int'=None,reserved:'typing.Any'=0) -> 'win32typing.PyIDL':
    """
    Retrieves the PIDL of a folder.

Args:

      hwndOwner(typing.Any):Window in which to display any neccessary dialogs
      nFolder(typing.Any):One of the CSIDL_* constants specifying the path.
      hToken(int):An access token that can be used to represent a particular user, or None
      reserved(typing.Any):Must be 0CommentsThis method is only available with version 5 or later of the shell controls

Returns:

      win32typing.PyIDL
        
    """
    pass
        

def SHGetNameFromIDList(pidl:'win32typing.PyIDL',flags:'typing.Any') -> 'typing.Any':
    """
    Retrieves the display name of an item from an ID list.

Args:

      pidl(win32typing.PyIDL):Absolute ID list of the item
      flags(typing.Any):Type of name to return, shellcon.SIGDN_*CommentsThis function is only available on Vista and later; a COM exception with E_NOTIMPL will be thrown if the function can't be located.

Returns:

      typing.Any
        
    """
    pass
        

def SHGetSpecialFolderPath(hwndOwner:'int',nFolder:'typing.Any',bCreate:'typing.Any'=0) -> 'str':
    """
    Retrieves the path of a special folder.

Args:

      hwndOwner(int):Parent window, can be None (or 0)
      nFolder(typing.Any):One of the CSIDL_* constants specifying the path.
      bCreate(typing.Any):Should the path be created.CommentsThis method is only available in shell version 4.71.  If the function is not available, a COM Exception with HRESULT=E_NOTIMPL will be raised.  If the function fails, a COM Exception with HRESULT=E_FAIL will be raised.

Returns:

      str
        
    """
    pass
        

def SHGetSpecialFolderLocation(hwndOwner:'int',nFolder:'typing.Any') -> 'win32typing.PyIDL':
    """
    Retrieves the PIDL of a special folder.

Args:

      hwndOwner(int):Parent window, can be None (or 0)
      nFolder(typing.Any):One of the CSIDL_* constants specifying the path.

Returns:

      win32typing.PyIDL
        
    """
    pass
        

def SHAddToRecentDocs(Flags:'typing.Any',data:'typing.Any') -> 'None':
    """
    Adds a document to the shell's list of recently used documents or clears all 

documents from the list. The user gains access to the list through the Start menu of the Windows taskbar.

Args:

      Flags(typing.Any):Value from SHARD enum indicating how the item is identified.
      data(typing.Any):Type of input is determined by the SHARD_* flag.  Use None to clear recent items list.FlagsType of inputSHARD_PATHAString containing a file pathSHARD_PATHWString containing a file pathSHARD_PIDLPyIDL, or a buffer containing a PIDL (see shell::PIDLAsString)SHARD_APPIDINFOTuple of (PyIShellItem, str), where str is an AppIDSHARD_APPIDINFOIDLISTTuple of (PyIDL, str), where str is an AppIDSHARD_LINKPyIShellLinkSHARD_APPIDINFOLINKTuple of (PyIShellLink, str) where str is an AppIDSHARD_SHELLITEMPyIShellItemCommentsOn Windows 7, the entry is also added to the application's jump list.The underlying API function has no return value, and therefore no way to indicate failure.Win32 API References

Returns:

      None
        
    """
    pass
        

def SHChangeNotify(EventId:'typing.Any',Flags:'typing.Any',Item1:'typing.Any',Item2:'typing.Any') -> 'None':
    """
    Notifies the system of an event that an application has performed. An application 

should use this function if it performs an action that may affect the shell.

Args:

      EventId(typing.Any):Combination of shellcon.SHCNE_* constants
      Flags(typing.Any):Combination of shellcon.SHCNF_* constants that specify type of last 2 parameters Only one of the type flags may be specified, combined with one of the SHCNF_FLUSH* flags
      Item1(typing.Any):Type is dependent on the event to be signalled
      Item2(typing.Any):Type is dependent on the event to be signalled

Returns:

      None
        
    """
    pass
        

def SHEmptyRecycleBin(hwnd:'int',path:'str',flags:'typing.Any') -> 'None':
    """
    Empties the recycle bin on the specified drive.

Args:

      hwnd(int):Handle to parent window, can be None
      path(str):A NULL-terminated string that contains the path of the root drive on which the recycle bin is located. This parameter can contain the address of a string formatted with the drive, folder, and subfolder names (c:\\windows\\system . . .). It can also contain an empty string or NULL. If this value is an empty string or NULL, all recycle bins on all drives will be emptied.
      flags(typing.Any):One of the SHERB_* values.CommentsThis method is only available in shell version 4.71.  If the function is not available, a COM Exception with HRESULT=E_NOTIMPL will be raised.

Returns:

      None
        
    """
    pass
        

def SHQueryRecycleBin(RootPath:'str'=None) -> 'typing.Tuple[typing.Any, typing.Any]':
    """
    Retrieves the total size and number of items in the Recycle Bin for a 

specified drive

Args:

      RootPath(str):A path containing the drive whose recycle bin will be queried, or None for all drives

Returns:

      typing.Tuple[typing.Any, typing.Any]
        
    """
    pass
        

def SHGetDesktopFolder() -> 'win32typing.PyIShellFolder':
    """
    None

Args:



Returns:

      win32typing.PyIShellFolder
        
    """
    pass
        

def SHUpdateImage(HashItem:'str',Index:'typing.Any',Flags:'typing.Any',ImageIndex:'typing.Any') -> 'None':
    """
    Notifies the shell that an image in the system image list has changed.

Args:

      HashItem(str):Full path of file containing the icon as returned by PyIExtractIcon::GetIconLocation
      Index(typing.Any):Index of the icon in the above file
      Flags(typing.Any):GIL_NOTFILENAME or GIL_SIMULATEDOC
      ImageIndex(typing.Any):Index of the icon in the system image list

Returns:

      None
        
    """
    pass
        

def SHChangeNotify(EventId:'typing.Any',Flags:'typing.Any',Item1:'typing.Any',Item2:'typing.Any') -> 'None':
    """
    Notifies the system of an event that an application has performed. An application 

should use this function if it performs an action that may affect the shell.

Args:

      EventId(typing.Any):Combination of shellcon.SHCNE_* constants
      Flags(typing.Any):Combination of shellcon.SHCNF_* constants that specify type of last 2 parameters Only one of the type flags may be specified, combined with one of the SHCNF_FLUSH* flags
      Item1(typing.Any):Type is dependent on the event to be signalled
      Item2(typing.Any):Type is dependent on the event to be signalled

Returns:

      None
        
    """
    pass
        

def SHChangeNotifyRegister(hwnd:'int',sources:'typing.Any',events:'typing.Any',msg:'typing.Any') -> 'typing.Any':
    """
    Registers a window that receives notifications from the file system or 

shell.

Args:

      hwnd(int):Handle to the window that receives the change or notification messages.
      sources(typing.Any):One or more values that indicate the type of events for which to receive notifications.
      events(typing.Any):Change notification events for which to receive notification.
      msg(typing.Any):Message to be posted to the window procedure.

Returns:

      typing.Any
        
    """
    pass
        

def SHChangeNotifyDeregister(_id:'typing.Any') -> 'None':
    """
    Unregisters the client's window process from receiving notification events

Args:

      _id(typing.Any):The registration identifier (ID) returned by shell::SHChangeNotifyRegister.

Returns:

      None
        
    """
    pass
        

def SHCreateItemFromIDList(pidl:'win32typing.PyIDL',riid:'win32typing.PyIID') -> 'win32typing.PyIShellItem':
    """
    None

Args:

      pidl(win32typing.PyIDL):An absolute item identifier list
      riid(win32typing.PyIID):The interface to createCommentsThis function is only available on Vista and later; a COM exception with E_NOTIMPL will be thrown if the function can't be located.

Returns:

      win32typing.PyIShellItem
        
    """
    pass
        

def SHCreateItemFromParsingName(name:'typing.Any',ctx:'win32typing.PyIBindCtx',riid:'win32typing.PyIID') -> 'win32typing.PyIShellItem':
    """
    Creates and initializes a Shell item object from a 

parsing name.

Args:

      name(typing.Any):The display name of the item to create, eg a file path
      ctx(win32typing.PyIBindCtx):Bind context, can be None
      riid(win32typing.PyIID):The interface to create, IID_IShellItem or IID_IShellItem2CommentsThis function is only available on Vista and later; a COM exception with E_NOTIMPL will be thrown if the function can't be located.

Returns:

      win32typing.PyIShellItem
        
    """
    pass
        

def SHCreateItemFromRelativeName(Parent:'win32typing.PyIShellItem',Name:'typing.Any',ctx:'win32typing.PyIBindCtx',riid:'win32typing.PyIID') -> 'win32typing.PyIShellItem':
    """
    Creates and initializes a Shell item object from a 

relative parsing name.

Args:

      Parent(win32typing.PyIShellItem):Shell item interface on the parent folder
      Name(typing.Any):Relative name of an item within the parent folder
      ctx(win32typing.PyIBindCtx):Bind context for parsing, can be None
      riid(win32typing.PyIID):The interface to return, IID_IShellItem or IID_IShellItem2CommentsThis function is only available on Vista and later; a COM exception with E_NOTIMPL will be thrown if the function can't be located.

Returns:

      win32typing.PyIShellItem
        
    """
    pass
        

def SHCreateItemInKnownFolder(FolderId:'win32typing.PyIID',Flags:'typing.Any',Name:'typing.Any',riid:'win32typing.PyIID') -> 'win32typing.PyIShellItem':
    """
    Creates a Shell item object for a single file that exists 

inside a known folder.

Args:

      FolderId(win32typing.PyIID):The GUID of a known folder (shell.FOLDERID_*)
      Flags(typing.Any):Combination of shellcon.KF_FLAG_* flags controlling how folder is handled
      Name(typing.Any):Name of an item in the folder.  Pass None to bind to the known folder itself.
      riid(win32typing.PyIID):The interface to return, usually IID_IShellItem or IID_IShellItem2CommentsThis function is only available on Vista and later; a COM exception with E_NOTIMPL will be thrown if the function can't be located.

Returns:

      win32typing.PyIShellItem
        
    """
    pass
        

def SHCreateItemWithParent(Parent:'win32typing.PyIDL',sfParent:'win32typing.PyIShellFolder',child:'win32typing.PyIDL',riid:'win32typing.PyIID') -> 'win32typing.PyIShellItem':
    """
    Create a Shell item, given a parent folder and a child item 

ID.

Args:

      Parent(win32typing.PyIDL):Absolute item id list of the parent folder.  Pass None if the below shell folder is used.
      sfParent(win32typing.PyIShellFolder):Parent folder object.  Can be None if parent id list is specified.
      child(win32typing.PyIDL):Relative item id list for an object in the parent folder
      riid(win32typing.PyIID):The interface to return, usually IID_IShellItem or IID_IShellItem2CommentsThis function is only available on Vista and later; a COM exception with E_NOTIMPL will be thrown if the function can't be located.

Returns:

      win32typing.PyIShellItem
        
    """
    pass
        

def SHGetIDListFromObject(unk:'win32typing.PyIUnknown') -> 'win32typing.PyIDL':
    """
    Retrieves the PIDL of an object.

Args:

      unk(win32typing.PyIUnknown):CommentsThis function is only available on Vista and later; a COM exception with E_NOTIMPL will be thrown if the function can't be located.

Returns:

      win32typing.PyIDL
        
    """
    pass
        

def SHGetInstanceExplorer() -> 'win32typing.PyIUnknown':
    """
    Allows components that run in a Web browser (Iexplore.exe) or a 

nondefault Windows Explorer (Explorer.exe) process to hold a reference to the process. The components can use the 

reference to prevent the process from closing prematurely.

Args:



Returns:

      win32typing.PyIUnknown
        
    """
    pass
        

def SHFileOperation(operation:'win32typing.SHFILEOPSTRUCT') -> 'typing.Tuple[typing.Any, typing.Any]':
    """
    Copies, moves, renames, or deletes a file system object.

Args:

      operation(win32typing.SHFILEOPSTRUCT):Defines the operation to perform.Return ValueThe result is a tuple containing int result of the function itself, and the result of the fAnyOperationsAborted member after the operation.  If Flags contains FOF_WANTMAPPINGHANDLE, returned tuple will have a 3rd member containing a sequence of 2-tuples with the old and new file names of renamed files.  This will only have any content if FOF_RENAMEONCOLLISION was specified, and some filename conflicts actually occurred.

Returns:

      typing.Tuple[typing.Any, typing.Any]:Defines the operation to perform.Return ValueThe result is a tuple containing int result of the function itself, and the result of the 

fAnyOperationsAborted member after the operation.  If Flags contains FOF_WANTMAPPINGHANDLE, 

returned tuple will have a 3rd member containing a sequence of 2-tuples with the old and new file names 

of renamed files.  This will only have any content if FOF_RENAMEONCOLLISION was specified, and some 

filename conflicts actually occurred.

        
    """
    pass
        

def StringAsCIDA(pidl:'str') -> 'typing.Tuple[win32typing.PyIDL, typing.Any]':
    """
    Given a CIDA as a raw string, return the folder PIDL and list of 

children

Args:

      pidl(str):The PIDL as a raw string.Return ValueThe result is the PIDL of the folder, and a list of child PIDLs.

Returns:

      typing.Tuple[win32typing.PyIDL, typing.Any]:The PIDL as a raw string.Return ValueThe result is the PIDL of the folder, and a list of child PIDLs.

        
    """
    pass
        

def CIDAAsString(pidl:'str') -> 'str':
    """
    Given a (pidl, child_pidls) object, return a CIDA as a string

Args:

      pidl(str):The PIDL as a raw string.Return ValueThe result is a string with the CIDA bytes.

Returns:

      str:The PIDL as a raw string.Return ValueThe result is a string with the CIDA bytes.

        
    """
    pass
        

def StringAsPIDL(pidl:'str') -> 'win32typing.PyIDL':
    """
    Given a PIDL as a raw string, return a PIDL object (ie, a list of strings)

Args:

      pidl(str):The PIDL as a raw string.

Returns:

      win32typing.PyIDL
        
    """
    pass
        

def AddressAsPIDL(address:'typing.Any') -> 'win32typing.PyIDL':
    """
    Given the address of a PIDL in memory, return a PIDL object (ie, a list of 

strings)

Args:

      address(typing.Any):The address of the PIDL

Returns:

      win32typing.PyIDL
        
    """
    pass
        

def PIDLAsString(pidl:'win32typing.PyIDL') -> 'str':
    """
    Given a PIDL object, return the raw PIDL bytes as a string

Args:

      pidl(win32typing.PyIDL):The PIDL object (ie, a list of strings)

Returns:

      str
        
    """
    pass
        

def SHGetSettings(mask:'typing.Any'=-1) -> 'typing.Any':
    """
    Retrieves the current shell option settings.

Args:

      mask(typing.Any):The values being requested - one of the shellcon.SSF_* constantsCommentsThis method is only available in shell version 4.71.  If the function is not available, a COM Exception with HRESULT=E_NOTIMPL will be raised.Return ValueThe result is a dictionary, the contents of which depend on the mask param.  Key names are the same as the SHELLFLAGSTATE structure members - 'fShowExtensions', 'fNoConfirmRecycle', etc

Returns:

      typing.Any:The values being requested - one of the shellcon.SSF_* constants
Comments

This method is only available in shell version 4.71.  If the 

function is not available, a COM Exception with HRESULT=E_NOTIMPL 

will be raised.
Return ValueThe result is a dictionary, the contents of which depend on 

the mask param.  Key names are the same as the SHELLFLAGSTATE 

structure members - 'fShowExtensions', 'fNoConfirmRecycle', etc

        
    """
    pass
        

def FILEGROUPDESCRIPTORAsString(descriptors:'typing.List[typing.Any]',arg:'typing.Any') -> 'str':
    """
    Creates a FILEGROUPDESCRIPTOR from a sequence of mapping objects, 

each with FILEDESCRIPTOR attributes

Args:

      descriptors(typing.List[typing.Any]):A sequence of FILEDESCRIPTOR objects. Each filedescriptor object must be a mapping/dictionary, with the following optional attributes: dwFlags, clsid, sizel, pointl, dwFileAttributes, ftCreationTime, ftLastAccessTime, ftLastWriteTime, nFileSize If these attributes do not exist, or are None, they will be ignored - hence you only need specify attributes you care about. In general, you can omit dwFlags - it will be set correctly based on what other attributes exist.
      arg(typing.Any):If true, a FILEDESCRIPTORW object is created

Returns:

      str
        
    """
    pass
        

def StringAsFILEGROUPDESCRIPTOR(buf:'typing.Any',make_unicode:'typing.Any'=-1) -> 'typing.List[typing.Any]':
    """
    Decodes a FILEGROUPDESCRIPTOR packed in a string

Args:

      buf(typing.Any):A string packed as either FILEGROUPDESCRIPTORW or FILEGROUPDESCRIPTORW
      make_unicode(typing.Any):Should this be treated as a FILEDESCRIPTORW?  If -1 the size of the buffer will be used to make that determination.  Thus, if the buffer is not the exact size of a correct FILEDESCRIPTORW or FILEDESCRIPTORA, you will need to specify this parameter.

Returns:

      typing.List[typing.Any]
        
    """
    pass
        

def ShellExecuteEx(lpVerb:'str',lpFile:'str',lpParameters:'str',lpDirectory:'str',lpIDList:'win32typing.PyIDL',obClass:'str',hkeyClass:'typing.Any',dwHotKey:'typing.Any',hIcon:'int',hMonitor:'int',fMask:'typing.Any'=0,hwnd:'int'=0,nShow:'typing.Any'=0) -> 'typing.Any':
    """
    Performs an operation on a file.

Args:

      lpVerb(str):
      lpFile(str):
      lpParameters(str):
      lpDirectory(str):
      lpIDList(win32typing.PyIDL):
      obClass(str):
      hkeyClass(typing.Any):
      dwHotKey(typing.Any):
      hIcon(int):
      hMonitor(int):Return ValueThe result is a dictionary based on documented result values in the structure.  Currently this is "hInstApp" and "hProcess"
      fMask(typing.Any):The default mask for the structure.  Other masks may be added based on what paramaters are supplied.
      hwnd(int):
      nShow(typing.Any):

Returns:

      typing.Any:Return ValueThe result is a dictionary based on documented result values 

in the structure.  Currently this is "hInstApp" and "hProcess"

        
    """
    pass
        

def SHGetViewStatePropertyBag(pidl:'win32typing.PyIDL',BagName:'str',Flags:'typing.Any',riid:'win32typing.PyIID') -> 'win32typing.PyIPropertyBag':
    """
    Retrieves an interface for the view state of a folder

Args:

      pidl(win32typing.PyIDL):An item id list that identifies the folder
      BagName(str):Name of the property bag to retrieve
      Flags(typing.Any):Combination of SHGVSPB_* flags
      riid(win32typing.PyIID):The interface to return, usually IID_IPropertyBagCommentsThis function will also return IPropertyBag2, but we don't have a python implementation of this interface yet

Returns:

      win32typing.PyIPropertyBag
        
    """
    pass
        

def SHILCreateFromPath(Path:'str',Flags:'typing.Any') -> 'typing.Tuple[win32typing.PyIDL, typing.Any]':
    """
    Retrieves the PIDL and attributes for a path

Args:

      Path(str):The path whose PIDL will be returned
      Flags(typing.Any):A combination of SFGAO_* constants as used with GetAttributesOfReturn ValueReturns the PIDL for the given path and any requested attributes

Returns:

      typing.Tuple[win32typing.PyIDL, typing.Any]:A combination of SFGAO_* constants as used with GetAttributesOfReturn ValueReturns the PIDL for the given path and any requested attributes

        
    """
    pass
        

def SHCreateShellItem(pidlParent:'win32typing.PyIDL',sfParent:'win32typing.PyIShellFolder',Child:'win32typing.PyIDL') -> 'win32typing.PyIShellItem':
    """
    Creates an IShellItem interface from a PIDL

Args:

      pidlParent(win32typing.PyIDL):PIDL of parent folder, can be None
      sfParent(win32typing.PyIShellFolder):IShellFolder interface of parent folder, can be None
      Child(win32typing.PyIDL):PIDL identifying desired item.  Must be an absolute PIDL if parent is not specified.CommentsThis function is only available on XP and later; a COM exception with E_NOTIMPL will be thrown if the function can't be located.

Returns:

      win32typing.PyIShellItem
        
    """
    pass
        

def SHOpenFolderAndSelectItems(Folder:'win32typing.PyIDL',Items:'typing.Tuple[win32typing.PyIDL, ...]',Flags:'typing.Any'=0) -> 'None':
    """
    Displays a shell folder with items pre-selected

Args:

      Folder(win32typing.PyIDL):An absolute item id list identifying a shell folder
      Items(typing.Tuple[win32typing.PyIDL, ...]):A sequence of relative item ids identifying items in the folder
      Flags(typing.Any):Combination of OFASI_* flags (not used on XP)CommentsThis function is only available on XP and later. COM exception with E_NOTIMPL will be thrown if the function can't be located.

Returns:

      None
        
    """
    pass
        

def SHCreateStreamOnFileEx(File:'typing.Any',Mode:'typing.Any',Attributes:'typing.Any',Create:'typing.Any',Template:'typing.Any'=None) -> 'win32typing.PyIStream':
    """
    Creates an IStream interface that reads and writes to a file

Args:

      File(typing.Any):Name of file to be connected to the stream
      Mode(typing.Any):Combination of storagecon.STGM_* flags specifying the access mode
      Attributes(typing.Any):Combination of win32con.FILE_ATTRIBUTE_* flags
      Create(typing.Any):Determines if function should fail when file exists (see MSDN docs for full explanation)
      Template(typing.Any):Reserved, use only NoneCommentsAccepts keyword args.This function is only available on WinXP and later. COM exception with E_NOTIMPL will be thrown if the function can't be located.

Returns:

      win32typing.PyIStream
        
    """
    pass
        

def SetCurrentProcessExplicitAppUserModelID(AppID:'typing.Any') -> 'None':
    """
    Sets the taskbar identifier

Args:

      AppID(typing.Any):The Application User Model ID used to group taskbar buttonsCommentsShould be used early in process startup before creating any windowsRequires Windows 7 or later

Returns:

      None
        
    """
    pass
        

def GetCurrentProcessExplicitAppUserModelID() -> 'typing.Any':
    """
    Retrieves the current taskbar identifier

Args:



Returns:

      typing.Any
        
    """
    pass
        

def SHParseDisplayName(Name:'typing.Any',Attributes:'typing.Any',BindCtx:'win32typing.PyIBindCtx'=None) -> 'typing.Tuple[win32typing.PyIDL, typing.Any]':
    """
    Translates a display name into a shell item identifier

Args:

      Name(typing.Any):Display name of a shell item, such as a file path
      Attributes(typing.Any):Bitmask of shell attributes to retrieve, combination of shellcon.SFGAO_*
      BindCtx(win32typing.PyIBindCtx):Bind context, can be NoneCommentsAccepts keyword argsRequires XP or laterReturn ValueReturns the item id list and any requested attribute flags

Returns:

      typing.Tuple[win32typing.PyIDL, typing.Any]:Bind context, can be None
Comments

Accepts keyword args

Requires XP or later
Return ValueReturns the item id list and any requested attribute flags

        
    """
    pass
        


__all__=['', 'AfxOleInit', 'CreateInsertDialog', 'CreateOleClientItem', 'CreateOleDocument', 'DaoGetEngine', 'GetIDispatchForWindow', 'OleGetUserCtrl', 'OleSetUserCtrl', 'SetMessagePendingDelay', 'EnableNotRespondingDialog', 'EnableNotRespondingDialog', 'COleClientItem_activeState', 'COleClientItem_activeUIState', 'COleClientItem_emptyState', 'COleClientItem_loadedState', 'COleClientItem_openState', 'OLE_CHANGED', 'OLE_CHANGED_ASPECT', 'OLE_CHANGED_STATE', 'OLE_CLOSED', 'OLE_RENAMED', 'OLE_SAVED']
import typing
import win32typing
"""A module, encapsulating the Microsoft Foundation Classes OLE functionality."""


def AfxOleInit(enabled:'typing.Any') -> 'None':
    """
    None

Args:

      enabled(typing.Any):

Returns:

      None
        
    """
    pass
        

def CreateInsertDialog() -> 'win32typing.PyCOleInsertDialog':
    """
    Creates a InsertObject dialog. 

self*/, PyObject *args)

Args:



Returns:

      win32typing.PyCOleInsertDialog
        
    """
    pass
        

def CreateOleClientItem() -> 'win32typing.PyCOleClientItem':
    """
    None

Args:



Returns:

      win32typing.PyCOleClientItem
        
    """
    pass
        

def CreateOleDocument(template:'win32typing.PyCDocTemplate',fileName:'str'=None) -> 'win32typing.PyCOleDocument':
    """
    Creates an OLE document.

Args:

      template(win32typing.PyCDocTemplate):The template to be attached to this document.
      fileName(str):The filename for the document.

Returns:

      win32typing.PyCOleDocument
        
    """
    pass
        

def DaoGetEngine() -> 'win32typing.PyIDispatch':
    """
    None

Args:



Returns:

      win32typing.PyIDispatch
        
    """
    pass
        

def GetIDispatchForWindow() -> 'win32typing.PyIDispatch':
    """
    Gets an OCX IDispatch pointer, if the window has one!

Args:



Returns:

      win32typing.PyIDispatch
        
    """
    pass
        

def OleGetUserCtrl() -> 'typing.Any':
    """
    Returns the application name.

Args:



Returns:

      typing.Any
        
    """
    pass
        

def OleSetUserCtrl(bUserCtrl:'typing.Any') -> 'typing.Any':
    """
    Sets or clears the user control flag.

Args:

      bUserCtrl(typing.Any):Specifies whether the user-control flag is to be set or cleared.

Returns:

      typing.Any
        
    """
    pass
        

def SetMessagePendingDelay(delay:'typing.Any') -> 'None':
    """
    None

Args:

      delay(typing.Any):

Returns:

      None
        
    """
    pass
        

def EnableNotRespondingDialog(enabled:'typing.Any') -> 'None':
    """
    None

Args:

      enabled(typing.Any):

Returns:

      None
        
    """
    pass
        

def EnableNotRespondingDialog(enabled:'typing.Any') -> 'None':
    """
    None

Args:

      enabled(typing.Any):

Returns:

      None
        
    """
    pass
        
COleClientItem_activeState = ...
COleClientItem_activeUIState = ...
COleClientItem_emptyState = ...
COleClientItem_loadedState = ...
COleClientItem_openState = ...
OLE_CHANGED = ...
OLE_CHANGED_ASPECT = ...
OLE_CHANGED_STATE = ...
OLE_CLOSED = ...
OLE_RENAMED = ...
OLE_SAVED = ...



__all__=['', 'error', 'DosDateTimeToTime', 'Unicode', 'UnicodeFromRaw', 'IsTextUnicode', 'OVERLAPPED', 'IID', 'Time', 'Time', 'CreateGuid', 'ACL', 'SID', 'SECURITY_ATTRIBUTES', 'SECURITY_DESCRIPTOR', 'HANDLE', 'HKEY', 'WAVEFORMATEX']
import typing
import win32typing
"""A module which supports common Windows types."""


class error(Exception):
    pass


def DosDateTimeToTime() -> 'win32typing.PyTime':
    """
    Converts an MS-DOS Date/Time to a standard Time object.

Args:



Returns:

      win32typing.PyTime
        
    """
    pass
        

def Unicode() -> 'str':
    """
    Creates a new Unicode object

Args:



Returns:

      str
        
    """
    pass
        

def UnicodeFromRaw(_str:'typing.Union[str, typing.Any]') -> 'str':
    """
    Creates a new Unicode object from raw binary data

Args:

      _str(typing.Union[str, typing.Any]):The string containing the binary data.

Returns:

      str
        
    """
    pass
        

def IsTextUnicode(_str:'str',flags:'typing.Any') -> 'typing.Tuple[typing.Any, typing.Any]':
    """
    Determines whether a buffer probably contains a form of Unicode text.

Args:

      _str(str):The string containing the binary data.
      flags(typing.Any):Determines the specific tests to makeReturn ValueThe function returns (result, flags), both integers. result is nonzero if the data in the buffer passes the specified tests. result is zero if the data in the buffer does not pass the specified tests. In either case, flags contains the results of the specific tests the function applied to make its determination.

Returns:

      typing.Tuple[typing.Any, typing.Any]:Determines the specific tests to makeReturn ValueThe function returns (result, flags), both integers. 

result is nonzero if the data in the buffer passes the specified tests. 

result is zero if the data in the buffer does not pass the specified tests. 

In either case, flags contains the results of the specific tests the function applied to make its 

determination.

        
    """
    pass
        

def OVERLAPPED() -> 'win32typing.PyOVERLAPPED':
    """
    Creates a new OVERLAPPED object

Args:



Returns:

      win32typing.PyOVERLAPPED
        
    """
    pass
        

def IID(iidString:'typing.Union[str, typing.Any]',is_bytes:'typing.Any'=False) -> 'win32typing.PyIID':
    """
    Creates a new IID object

Args:

      iidString(typing.Union[str, typing.Any]):A string representation of an IID, or a ProgID.
      is_bytes(typing.Any):Indicates if the first param is actually the bytes of an IID structure.

Returns:

      win32typing.PyIID
        
    """
    pass
        

def Time(timeRepr:'typing.Any') -> 'win32typing.PyTime':
    """
    Creates a new time object.

Args:

      timeRepr(typing.Any):An integer/float/tuple time representation.CommentsNote that the parameter can be any object that supports int(object) - for example , another PyTime object. The integer should be as defined by the Python time module. See the description of the PyTime object for more information.

Returns:

      win32typing.PyTime
        
    """
    pass
        

def Time(timeRepr:'typing.Any') -> 'win32typing.PyTime':
    """
    Creates a new time object.

Args:

      timeRepr(typing.Any):An integer/float/tuple time representation.CommentsNote that the parameter can be any object that supports int(object) - for example , another PyTime object. The integer should be as defined by the Python time module. See the description of the PyTime object for more information.

Returns:

      win32typing.PyTime
        
    """
    pass
        

def CreateGuid() -> 'win32typing.PyIID':
    """
    Creates a new, unique GUIID.

Args:



Returns:

      win32typing.PyIID
        
    """
    pass
        

def ACL(bufSize:'typing.Any'=64) -> 'win32typing.PyACL':
    """
    Creates a new ACL object

Args:

      bufSize(typing.Any):The size for the ACL.

Returns:

      win32typing.PyACL
        
    """
    pass
        

def SID(buffer:'typing.Any',idAuthority:'typing.Any',subAuthorities:'typing.Any',bufSize:'typing.Any'=32) -> 'win32typing.PySID':
    """
    Creates a new SID object

Args:

      buffer(typing.Any):A raw data buffer, assumed to hold the SID data.Alternative Parameters
      idAuthority(typing.Any):The identifier authority.
      subAuthorities(typing.Any):A list of sub authorities.
      bufSize(typing.Any):Size for the SID bufferAlternative Parameters

Returns:

      win32typing.PySID
        
    """
    pass
        

def SECURITY_ATTRIBUTES() -> 'win32typing.PySECURITY_ATTRIBUTES':
    """
    Creates a new SECURITY_ATTRIBUTES object

Args:



Returns:

      win32typing.PySECURITY_ATTRIBUTES
        
    """
    pass
        

def SECURITY_DESCRIPTOR() -> 'win32typing.PySECURITY_DESCRIPTOR':
    """
    Creates a new SECURITY_DESCRIPTOR object

Args:



Returns:

      win32typing.PySECURITY_DESCRIPTOR
        
    """
    pass
        

def HANDLE() -> 'int':
    """
    Creates a new HANDLE object

Args:



Returns:

      int
        
    """
    pass
        

def HKEY() -> 'win32typing.PyHKEY':
    """
    Creates a new HKEY object

Args:



Returns:

      win32typing.PyHKEY
        
    """
    pass
        

def WAVEFORMATEX() -> 'win32typing.PyWAVEFORMATEX':
    """
    Creates a new WAVEFORMATEX object

Args:



Returns:

      win32typing.PyWAVEFORMATEX
        
    """
    pass
        


__all__=['', 'set_timer', 'kill_timer']
import typing
import win32typing
"""Extension that wraps Win32 Timer functions"""


def set_timer(Elapse:'typing.Any',TimerFunc:'typing.Any') -> 'typing.Any':
    """
    Creates a timer that executes a callback function

Args:

      Elapse(typing.Any):Timer period, in milliseconds
      TimerFunc(typing.Any):Callback function.  Will be called with with 2 int args: (timer_id, time)CommentsUses the SetTimer function.Return ValueReturns the id of the timer, which can be passed to kill_timer to stop it.

Returns:

      typing.Any:Callback function.  Will be called with with 2 int 

args: (timer_id, time)Comments

Uses the SetTimer function.
Return ValueReturns the id of the timer, which can be passed to kill_timer to stop it.

        
    """
    pass
        

def kill_timer(IDEvent:'typing.Any') -> 'typing.Any':
    """
    Creates a timer that executes a callback function

Args:

      IDEvent(typing.Any):Timer id as returned by timer::set_timerCommentsUses the KillTimer API function.

Returns:

      typing.Any
        
    """
    pass
        